Class: Google::Apis::NetworkservicesV1::AgentGateway
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::AgentGateway
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
AgentGateway represents the agent gateway resource.
Instance Attribute Summary collapse
-
#agent_connectivity_template ⇒ String
Optional.
-
#agent_gateway_card ⇒ Google::Apis::NetworkservicesV1::AgentGatewayAgentGatewayOutputCard
AgentGatewayOutputCard contains informational output-only fields Corresponds to the JSON property
agentGatewayCard. -
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#google_managed ⇒ Google::Apis::NetworkservicesV1::AgentGatewayGoogleManaged
Configuration for Google Managed deployment mode.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#network_config ⇒ Google::Apis::NetworkservicesV1::AgentGatewayNetworkConfig
NetworkConfig contains network configurations for the AgentGateway.
-
#protocols ⇒ Array<String>
Optional.
-
#registries ⇒ Array<String>
Optional.
-
#self_managed ⇒ Google::Apis::NetworkservicesV1::AgentGatewaySelfManaged
Configuration for Self Managed deployment mode.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentGateway
constructor
A new instance of AgentGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentGateway
Returns a new instance of AgentGateway.
191 192 193 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_connectivity_template ⇒ String
Optional. The resource name of the AgentConnectivityTemplate. Format: projects/
project/locations/location/agentConnectivityTemplates/template
Corresponds to the JSON property agentConnectivityTemplate
121 122 123 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 121 def agent_connectivity_template @agent_connectivity_template end |
#agent_gateway_card ⇒ Google::Apis::NetworkservicesV1::AgentGatewayAgentGatewayOutputCard
AgentGatewayOutputCard contains informational output-only fields
Corresponds to the JSON property agentGatewayCard
126 127 128 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 126 def agent_gateway_card @agent_gateway_card end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
131 132 133 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 131 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
136 137 138 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 136 def description @description end |
#etag ⇒ String
Optional. Etag of the resource. If this is provided, it must match the server'
s etag. If the provided etag does not match the server's etag, the request
will fail with a 409 ABORTED error.
Corresponds to the JSON property etag
143 144 145 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 143 def etag @etag end |
#google_managed ⇒ Google::Apis::NetworkservicesV1::AgentGatewayGoogleManaged
Configuration for Google Managed deployment mode. Proxy is orchestrated and
managed by GoogleCloud in a tenant project.
Corresponds to the JSON property googleManaged
149 150 151 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 149 def google_managed @google_managed end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the AgentGateway resource.
Corresponds to the JSON property labels
154 155 156 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 154 def labels @labels end |
#name ⇒ String
Identifier. Name of the AgentGateway resource. It matches pattern projects/*/
locations/*/agentGateways/.
Corresponds to the JSON property name
160 161 162 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 160 def name @name end |
#network_config ⇒ Google::Apis::NetworkservicesV1::AgentGatewayNetworkConfig
NetworkConfig contains network configurations for the AgentGateway.
Corresponds to the JSON property networkConfig
165 166 167 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 165 def network_config @network_config end |
#protocols ⇒ Array<String>
Optional. Deprecated.
Corresponds to the JSON property protocols
170 171 172 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 170 def protocols @protocols end |
#registries ⇒ Array<String>
Optional. A list of Agent registries containing the agents, MCP servers and
tools governed by the Agent Gateway. Note: Currently limited to project-scoped
registries Must be of format //agentregistry.googleapis.com/projects/project
/locations/location/
Corresponds to the JSON property registries
178 179 180 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 178 def registries @registries end |
#self_managed ⇒ Google::Apis::NetworkservicesV1::AgentGatewaySelfManaged
Configuration for Self Managed deployment mode. Attach to existing Application
Load Balancers or Secure Web Proxies.
Corresponds to the JSON property selfManaged
184 185 186 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 184 def self_managed @self_managed end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
189 190 191 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 189 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 196 def update!(**args) @agent_connectivity_template = args[:agent_connectivity_template] if args.key?(:agent_connectivity_template) @agent_gateway_card = args[:agent_gateway_card] if args.key?(:agent_gateway_card) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @google_managed = args[:google_managed] if args.key?(:google_managed) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network_config = args[:network_config] if args.key?(:network_config) @protocols = args[:protocols] if args.key?(:protocols) @registries = args[:registries] if args.key?(:registries) @self_managed = args[:self_managed] if args.key?(:self_managed) @update_time = args[:update_time] if args.key?(:update_time) end |