Class: Google::Apis::NetworkservicesV1::ExtensionBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

ExtensionBinding is a resource representing the attachment of an extension to a service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionBinding

Returns a new instance of ExtensionBinding.



1103
1104
1105
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1030
1031
1032
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1030

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


1035
1036
1037
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1035

def description
  @description
end

#etagString

Optional. Etag of the resource. If provided, it must match the server's etag. If the provided etag does not match the server's etag, the request will fail with a 409 ABORTED error. Corresponds to the JSON property etag

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1042

def etag
  @etag
end

#fail_openBoolean Also known as: fail_open?

Optional. Determines the behavior of the extension binding when the call to the extension fails or times out. Default value is FALSE. When set to TRUE, failures of the extension are silently ignored. Corresponds to the JSON property failOpen

Returns:

  • (Boolean)


1049
1050
1051
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1049

def fail_open
  @fail_open
end

#labelsHash<String,String>

Optional. Set of labels associated with the ExtensionBinding resource. The format must comply with the following requirements. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1057
1058
1059
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1057

def labels
  @labels
end

#match_conditionsArray<Google::Apis::NetworkservicesV1::ExtensionBindingMatchCondition>

Optional. A list of match conditions to match against the incoming request. The extension will be invoked if at least one condition matches the request, or if no match conditions are specified. Limited to 5 conditions. Corresponds to the JSON property matchConditions



1064
1065
1066
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1064

def match_conditions
  @match_conditions
end

#nameString

Identifier. Name of the ExtensionBinding resource in the following format: projects/project/locations/location/extensionBindings/extension_binding`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1070
1071
1072
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1070

def name
  @name
end

#priorityFixnum

Optional. Priority of the extension binding. Lower numbers indicate higher priority. Priority of extension bindings are used to determine the order in which extension bindings are applied to a request. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1077
1078
1079
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1077

def priority
  @priority
end

#producer_extensionString

Required. The name of the extension that this binding should attach to target resources. Format: For Google-provided extensions, specify the service endpoint (see Model Armor integration) Corresponds to the JSON property producerExtension

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1085

def producer_extension
  @producer_extension
end

#producer_metadataHash<String,String>

Optional. Additional metadata that should be passed to the attached extension with each request. Corresponds to the JSON property producerMetadata

Returns:

  • (Hash<String,String>)


1091
1092
1093
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1091

def 
  @producer_metadata
end

#targetGoogle::Apis::NetworkservicesV1::ExtensionBindingTarget

Specifies a list of targets to which this ExtensionBinding should attach. Corresponds to the JSON property target



1096
1097
1098
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1096

def target
  @target
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1101
1102
1103
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1101

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1108

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @fail_open = args[:fail_open] if args.key?(:fail_open)
  @labels = args[:labels] if args.key?(:labels)
  @match_conditions = args[:match_conditions] if args.key?(:match_conditions)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @producer_extension = args[:producer_extension] if args.key?(:producer_extension)
  @producer_metadata = args[:producer_metadata] if args.key?(:producer_metadata)
  @target = args[:target] if args.key?(:target)
  @update_time = args[:update_time] if args.key?(:update_time)
end