Class: Google::Apis::NetworkservicesV1::ExtensionBindingMatchCondition
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ExtensionBindingMatchCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Conditions to match against the incoming request.
Instance Attribute Summary collapse
-
#to ⇒ Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionTo
Describes properties of one or more destinations of a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchCondition
constructor
A new instance of ExtensionBindingMatchCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchCondition
Returns a new instance of ExtensionBindingMatchCondition.
1133 1134 1135 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#to ⇒ Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionTo
Describes properties of one or more destinations of a request.
Corresponds to the JSON property to
1131 1132 1133 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1131 def to @to end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1138 1139 1140 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1138 def update!(**args) @to = args[:to] if args.key?(:to) end |