Class: Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionToDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Describes properties of a single destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestination

Returns a new instance of ExtensionBindingMatchConditionToDestination.



1277
1278
1279
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_setGoogle::Apis::NetworkservicesV1::ExtensionBindingMatchConditionToDestinationHeaderSet

Describes a set of HTTP headers to match against. Corresponds to the JSON property headerSet



1252
1253
1254
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1252

def header_set
  @header_set
end

#hostsArray<Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionStringMatch>

Optional. A list of HTTP Hosts to match against. Limited to 10 hosts. If not specified, any host is allowed. If specified, a match occurs if any of the hosts matches the host value in the request. Corresponds to the JSON property hosts



1259
1260
1261
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1259

def hosts
  @hosts
end

#pathsArray<Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionStringMatch>

Optional. A list of paths to match against. Limited to 10 paths. If not specified, any path is allowed. Note that this path match includes the query parameters. For gRPC services, this should be a fully-qualified name of the form /package.service/method. Corresponds to the JSON property paths



1267
1268
1269
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1267

def paths
  @paths
end

#resourcesArray<Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionStringMatch>

Optional. A list of non-empty strings whose value is matched against the resource value. If not specified, any resource is allowed. If specified, a match occurs if any of the resources matches the resource value in the request. Limited to 5 resources. Corresponds to the JSON property resources



1275
1276
1277
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1275

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1282
1283
1284
1285
1286
1287
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1282

def update!(**args)
  @header_set = args[:header_set] if args.key?(:header_set)
  @hosts = args[:hosts] if args.key?(:hosts)
  @paths = args[:paths] if args.key?(:paths)
  @resources = args[:resources] if args.key?(:resources)
end