Class: Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionToDestinationHeaderSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Describes a set of HTTP headers to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestinationHeaderSet

Returns a new instance of ExtensionBindingMatchConditionToDestinationHeaderSet.



1301
1302
1303
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersArray<Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionHeaderMatch>

Required. A list of headers to match against in http header. If multiple header matches are provided, they will be evaluated as an AND, i.e. all header matches must match for the request to match. Corresponds to the JSON property headers



1299
1300
1301
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1299

def headers
  @headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1306
1307
1308
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1306

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
end