Class: Google::Apis::NetworkservicesV1::ExtensionBindingTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies a list of targets to which this ExtensionBinding should attach.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionBindingTarget

Returns a new instance of ExtensionBindingTarget.



1330
1331
1332
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resourcesArray<String>

Optional. The reference to the target resource, to which this binding should attach. Exactly one of resources or scope must be set. For Agent Gateway, this would be the full resource name, in the format: projects/project/ locations/location/agentGateways/agent_gateway. For AI App, this would be the full resource name, in the format: `projects/`project`/locations/`location` /applications/`application. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1323
1324
1325
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1323

def resources
  @resources
end

#scopeGoogle::Apis::NetworkservicesV1::ExtensionBindingTargetScope

Specifies the scope of resources to which this binding should attach. Corresponds to the JSON property scope



1328
1329
1330
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1328

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
1338
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1335

def update!(**args)
  @resources = args[:resources] if args.key?(:resources)
  @scope = args[:scope] if args.key?(:scope)
end