Class: Google::Apis::NetworkservicesV1::ExtensionBindingTargetScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies the scope of resources to which this binding should attach.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionBindingTargetScope

Returns a new instance of ExtensionBindingTargetScope.



1357
1358
1359
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. Parent resource name specification, in the format: projects/ project_number`. Corresponds to the JSON propertyparent`

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1349

def parent
  @parent
end

#resource_typesArray<String>

Required. Type of the resource to which the binding should attach. Limited to 1 resource type. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


1355
1356
1357
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1355

def resource_types
  @resource_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1362
1363
1364
1365
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1362

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
end