Class: Google::Apis::NetworkservicesV1::GrpcRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

GrpcRoute is the resource defining how gRPC traffic routed by a Mesh or Gateway resource is routed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRoute

Returns a new instance of GrpcRoute.



1891
1892
1893
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1819
1820
1821
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1819

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


1824
1825
1826
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1824

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this GrpcRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


1831
1832
1833
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1831

def gateways
  @gateways
end

#hostnamesArray<String>

Required. Service hostnames with an optional port for which this route describes traffic. Format: [:] Hostname is the fully qualified domain name of a network host. This matches the RFC 1123 definition of a hostname with 2 notable exceptions: - IPs are not allowed. - A hostname may be prefixed with a wildcard label (*.). The wildcard label must appear by itself as the first label. Hostname can be "precise" which is a domain name without the terminating dot of a network host (e.g. foo.example.com) or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. *.example. com). Note that as per RFC1035 and RFC1123, a label must consist of lower case alphanumeric characters or '-', and must start and end with an alphanumeric character. No other punctuation is allowed. The routes associated with a Mesh or Gateway must have unique hostnames. If you attempt to attach multiple routes with conflicting hostnames, the configuration will be rejected. For example, while it is acceptable for routes for the hostnames *.foo.bar. com and *.bar.com to be associated with the same route, it is not possible to associate two routes both with *.bar.com or both with bar.com. If a port is specified, then gRPC clients must use the channel URI with the port to match this rule (i.e. "xds:///service:123"), otherwise they must supply the URI without a port (i.e. "xds:///service"). Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


1854
1855
1856
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1854

def hostnames
  @hostnames
end

#labelsHash<String,String>

Optional. Set of label tags associated with the GrpcRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1859
1860
1861
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1859

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this GrpcRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


1866
1867
1868
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1866

def meshes
  @meshes
end

#nameString

Identifier. Name of the GrpcRoute resource. It matches pattern projects/*/ locations/*/grpcRoutes/ Corresponds to the JSON property name

Returns:

  • (String)


1872
1873
1874
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1872

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1::GrpcRouteRouteRule>

Required. A list of detailed rules defining how to route traffic. Within a single GrpcRoute, the GrpcRoute.RouteAction associated with the first matching GrpcRoute.RouteRule will be executed. At least one rule must be supplied. Corresponds to the JSON property rules



1879
1880
1881
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1879

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1884

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1889
1890
1891
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1889

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1896

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end