Class: Google::Apis::NetworkservicesV1::GrpcRouteFaultInjectionPolicyDelay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specification of how client requests are delayed as part of fault injection before being sent to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteFaultInjectionPolicyDelay

Returns a new instance of GrpcRouteFaultInjectionPolicyDelay.



2020
2021
2022
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_delayString

Specify a fixed delay before forwarding the request. Corresponds to the JSON property fixedDelay

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2012

def fixed_delay
  @fixed_delay
end

#percentageFixnum

The percentage of traffic on which delay will be injected. The value must be between [0, 100] Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


2018
2019
2020
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2018

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2025
2026
2027
2028
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2025

def update!(**args)
  @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay)
  @percentage = args[:percentage] if args.key?(:percentage)
end