Class: Google::Apis::NetworkservicesV1::GrpcRouteStatefulSessionAffinityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

The specification for cookie-based stateful session affinity where the date plane supplies a “session cookie” with the name "GSSA" which encodes a specific destination host and each request containing that cookie will be directed to that host as long as the destination host remains up and healthy. The gRPC proxyless mesh library or sidecar proxy will manage the session cookie but the client application code is responsible for copying the cookie from each RPC in the session to the next.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteStatefulSessionAffinityPolicy

Returns a new instance of GrpcRouteStatefulSessionAffinityPolicy.



1476
1477
1478
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Required. The cookie TTL value for the Set-Cookie header generated by the data plane. The lifetime of the cookie may be set to a value from 0 to 86400 seconds (24 hours) inclusive. Set this to 0s to use a session cookie and disable cookie expiration. Corresponds to the JSON property cookieTtl

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1474

def cookie_ttl
  @cookie_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1481
1482
1483
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1481

def update!(**args)
  @cookie_ttl = args[:cookie_ttl] if args.key?(:cookie_ttl)
end