Class: Google::Apis::NetworkservicesV1::HttpRouteCorsPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

The Specification for allowing client side cross-origin requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteCorsPolicy

Returns a new instance of HttpRouteCorsPolicy.



1677
1678
1679
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_credentialsBoolean Also known as: allow_credentials?

In response to a preflight request, setting this to true indicates that the actual request can include user credentials. This translates to the Access- Control-Allow-Credentials header. Default value is false. Corresponds to the JSON property allowCredentials

Returns:

  • (Boolean)


1632
1633
1634
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1632

def allow_credentials
  @allow_credentials
end

#allow_headersArray<String>

Specifies the content for Access-Control-Allow-Headers header. Corresponds to the JSON property allowHeaders

Returns:

  • (Array<String>)


1638
1639
1640
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1638

def allow_headers
  @allow_headers
end

#allow_methodsArray<String>

Specifies the content for Access-Control-Allow-Methods header. Corresponds to the JSON property allowMethods

Returns:

  • (Array<String>)


1643
1644
1645
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1643

def allow_methods
  @allow_methods
end

#allow_origin_regexesArray<String>

Specifies the regular expression patterns that match allowed origins. For regular expression grammar, please see https://github.com/google/re2/wiki/ Syntax. Corresponds to the JSON property allowOriginRegexes

Returns:

  • (Array<String>)


1650
1651
1652
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1650

def allow_origin_regexes
  @allow_origin_regexes
end

#allow_originsArray<String>

Specifies the list of origins that will be allowed to do CORS requests. An origin is allowed if it matches either an item in allow_origins or an item in allow_origin_regexes. Corresponds to the JSON property allowOrigins

Returns:

  • (Array<String>)


1657
1658
1659
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1657

def allow_origins
  @allow_origins
end

#disabledBoolean Also known as: disabled?

If true, the CORS policy is disabled. The default value is false, which indicates that the CORS policy is in effect. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1663
1664
1665
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1663

def disabled
  @disabled
end

#expose_headersArray<String>

Specifies the content for Access-Control-Expose-Headers header. Corresponds to the JSON property exposeHeaders

Returns:

  • (Array<String>)


1669
1670
1671
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1669

def expose_headers
  @expose_headers
end

#max_ageString

Specifies how long result of a preflight request can be cached in seconds. This translates to the Access-Control-Max-Age header. Corresponds to the JSON property maxAge

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1675

def max_age
  @max_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1682

def update!(**args)
  @allow_credentials = args[:allow_credentials] if args.key?(:allow_credentials)
  @allow_headers = args[:allow_headers] if args.key?(:allow_headers)
  @allow_methods = args[:allow_methods] if args.key?(:allow_methods)
  @allow_origin_regexes = args[:allow_origin_regexes] if args.key?(:allow_origin_regexes)
  @allow_origins = args[:allow_origins] if args.key?(:allow_origins)
  @disabled = args[:disabled] if args.key?(:disabled)
  @expose_headers = args[:expose_headers] if args.key?(:expose_headers)
  @max_age = args[:max_age] if args.key?(:max_age)
end