Class: Google::Apis::NetworkservicesV1::HttpRouteHeaderMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies how to select a route rule based on HTTP request headers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteHeaderMatch

Returns a new instance of HttpRouteHeaderMatch.



2641
2642
2643
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The value of the header should match exactly the content of exact_match. Corresponds to the JSON property exactMatch

Returns:

  • (String)


2598
2599
2600
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2598

def exact_match
  @exact_match
end

#headerString

The name of the HTTP header to match against. Corresponds to the JSON property header

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2603

def header
  @header
end

#invert_matchBoolean Also known as: invert_match?

If specified, the match result will be inverted before checking. Default value is set to false. Corresponds to the JSON property invertMatch

Returns:

  • (Boolean)


2609
2610
2611
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2609

def invert_match
  @invert_match
end

#prefix_matchString

The value of the header must start with the contents of prefix_match. Corresponds to the JSON property prefixMatch

Returns:

  • (String)


2615
2616
2617
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2615

def prefix_match
  @prefix_match
end

#present_matchBoolean Also known as: present_match?

A header with header_name must exist. The match takes place whether or not the header has a value. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


2621
2622
2623
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2621

def present_match
  @present_match
end

#range_matchGoogle::Apis::NetworkservicesV1::HttpRouteHeaderMatchIntegerRange

Represents an integer value range. Corresponds to the JSON property rangeMatch



2627
2628
2629
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2627

def range_match
  @range_match
end

#regex_matchString

The value of the header must match the regular expression specified in regex_match. For regular expression grammar, please see: https://github.com/ google/re2/wiki/Syntax Corresponds to the JSON property regexMatch

Returns:

  • (String)


2634
2635
2636
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2634

def regex_match
  @regex_match
end

#suffix_matchString

The value of the header must end with the contents of suffix_match. Corresponds to the JSON property suffixMatch

Returns:

  • (String)


2639
2640
2641
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2639

def suffix_match
  @suffix_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2646

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @header = args[:header] if args.key?(:header)
  @invert_match = args[:invert_match] if args.key?(:invert_match)
  @prefix_match = args[:prefix_match] if args.key?(:prefix_match)
  @present_match = args[:present_match] if args.key?(:present_match)
  @range_match = args[:range_match] if args.key?(:range_match)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
  @suffix_match = args[:suffix_match] if args.key?(:suffix_match)
end