Class: Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
The specification for modifying HTTP header in HTTP request and HTTP response.
Instance Attribute Summary collapse
-
#add ⇒ Hash<String,String>
Add the headers with given map where key is the name of the header, value is the value of the header.
-
#remove ⇒ Array<String>
Remove headers (matching by header names) specified in the list.
-
#set ⇒ Hash<String,String>
Completely overwrite/replace the headers with given map where key is the name of the header, value is the value of the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteHeaderModifier
constructor
A new instance of HttpRouteHeaderModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteHeaderModifier
Returns a new instance of HttpRouteHeaderModifier.
2183 2184 2185 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add ⇒ Hash<String,String>
Add the headers with given map where key is the name of the header, value is
the value of the header.
Corresponds to the JSON property add
2170 2171 2172 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2170 def add @add end |
#remove ⇒ Array<String>
Remove headers (matching by header names) specified in the list.
Corresponds to the JSON property remove
2175 2176 2177 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2175 def remove @remove end |
#set ⇒ Hash<String,String>
Completely overwrite/replace the headers with given map where key is the name
of the header, value is the value of the header.
Corresponds to the JSON property set
2181 2182 2183 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2181 def set @set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2188 2189 2190 2191 2192 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2188 def update!(**args) @add = args[:add] if args.key?(:add) @remove = args[:remove] if args.key?(:remove) @set = args[:set] if args.key?(:set) end |