Class: Google::Apis::NetworkservicesV1::HttpRouteRequestMirrorPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies the policy on how requests are shadowed to a separate mirrored destination service. The proxy does not wait for responses from the shadow service. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow. Mirroring is currently not supported for Cloud Run destinations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteRequestMirrorPolicy

Returns a new instance of HttpRouteRequestMirrorPolicy.



2375
2376
2377
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::NetworkservicesV1::HttpRouteDestination

Specifications of a destination to which the request should be routed to. Corresponds to the JSON property destination



2367
2368
2369
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2367

def destination
  @destination
end

#mirror_percentFloat

Optional. The percentage of requests to get mirrored to the desired destination. Corresponds to the JSON property mirrorPercent

Returns:

  • (Float)


2373
2374
2375
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2373

def mirror_percent
  @mirror_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2380
2381
2382
2383
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2380

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @mirror_percent = args[:mirror_percent] if args.key?(:mirror_percent)
end