Class: Google::Apis::NetworkservicesV1::ListGrpcRoutesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListGrpcRoutesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListGrpcRoutes method.
Instance Attribute Summary collapse
-
#grpc_routes ⇒ Array<Google::Apis::NetworkservicesV1::GrpcRoute>
List of GrpcRoute resources.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGrpcRoutesResponse
constructor
A new instance of ListGrpcRoutesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGrpcRoutesResponse
Returns a new instance of ListGrpcRoutesResponse.
3151 3152 3153 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#grpc_routes ⇒ Array<Google::Apis::NetworkservicesV1::GrpcRoute>
List of GrpcRoute resources.
Corresponds to the JSON property grpcRoutes
3135 3136 3137 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3135 def grpc_routes @grpc_routes end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3142 3143 3144 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3142 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when attempting to
list all resources across all supported locations.
Corresponds to the JSON property unreachable
3149 3150 3151 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3149 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3156 3157 3158 3159 3160 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3156 def update!(**args) @grpc_routes = args[:grpc_routes] if args.key?(:grpc_routes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |