Class: Google::Apis::NetworkservicesV1::ListHttpRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListHttpRoutes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListHttpRoutesResponse

Returns a new instance of ListHttpRoutesResponse.



3160
3161
3162
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_routesArray<Google::Apis::NetworkservicesV1::HttpRoute>

List of HttpRoute resources. Corresponds to the JSON property httpRoutes



3144
3145
3146
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3144

def http_routes
  @http_routes
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3151
3152
3153
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3151

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3158
3159
3160
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3158

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3165
3166
3167
3168
3169
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3165

def update!(**args)
  @http_routes = args[:http_routes] if args.key?(:http_routes)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end