Class: Google::Apis::NetworkservicesV1::ListLbRouteExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListLbRouteExtensionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Message for response to listing LbRouteExtension resources.
Instance Attribute Summary collapse
-
#lb_route_extensions ⇒ Array<Google::Apis::NetworkservicesV1::LbRouteExtension>
The list of
LbRouteExtensionresources. -
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLbRouteExtensionsResponse
constructor
A new instance of ListLbRouteExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLbRouteExtensionsResponse
Returns a new instance of ListLbRouteExtensionsResponse.
2943 2944 2945 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lb_route_extensions ⇒ Array<Google::Apis::NetworkservicesV1::LbRouteExtension>
The list of LbRouteExtension resources.
Corresponds to the JSON property lbRouteExtensions
2931 2932 2933 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2931 def lb_route_extensions @lb_route_extensions end |
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
Corresponds to the JSON property nextPageToken
2936 2937 2938 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2936 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2941 2942 2943 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2941 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2948 2949 2950 2951 2952 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2948 def update!(**args) @lb_route_extensions = args[:lb_route_extensions] if args.key?(:lb_route_extensions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |