Class: Google::Apis::NetworkservicesV1::ListLbTrafficExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListLbTrafficExtensionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Message for response to listing LbTrafficExtension resources.
Instance Attribute Summary collapse
-
#lb_traffic_extensions ⇒ Array<Google::Apis::NetworkservicesV1::LbTrafficExtension>
The list of
LbTrafficExtensionresources. -
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLbTrafficExtensionsResponse
constructor
A new instance of ListLbTrafficExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLbTrafficExtensionsResponse
Returns a new instance of ListLbTrafficExtensionsResponse.
2934 2935 2936 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lb_traffic_extensions ⇒ Array<Google::Apis::NetworkservicesV1::LbTrafficExtension>
The list of LbTrafficExtension resources.
Corresponds to the JSON property lbTrafficExtensions
2922 2923 2924 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2922 def lb_traffic_extensions @lb_traffic_extensions end |
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
Corresponds to the JSON property nextPageToken
2927 2928 2929 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2927 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2932 2933 2934 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2932 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2939 2940 2941 2942 2943 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2939 def update!(**args) @lb_traffic_extensions = args[:lb_traffic_extensions] if args.key?(:lb_traffic_extensions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |