Class: Google::Apis::NetworkservicesV1::ListMeshRouteViewsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListMeshRouteViews method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeshRouteViewsResponse

Returns a new instance of ListMeshRouteViewsResponse.



2993
2994
2995
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mesh_route_viewsArray<Google::Apis::NetworkservicesV1::MeshRouteView>

List of MeshRouteView resources. Corresponds to the JSON property meshRouteViews



2978
2979
2980
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2978

def mesh_route_views
  @mesh_route_views
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2984
2985
2986
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2984

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2991
2992
2993
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2991

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2998
2999
3000
3001
3002
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2998

def update!(**args)
  @mesh_route_views = args[:mesh_route_views] if args.key?(:mesh_route_views)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end