Class: Google::Apis::NetworkservicesV1::ListMeshesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListMeshes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeshesResponse

Returns a new instance of ListMeshesResponse.



3028
3029
3030
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#meshesArray<Google::Apis::NetworkservicesV1::Mesh>

List of Mesh resources. Corresponds to the JSON property meshes



3012
3013
3014
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3012

def meshes
  @meshes
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3019

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3026
3027
3028
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3026

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3033
3034
3035
3036
3037
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3033

def update!(**args)
  @meshes = args[:meshes] if args.key?(:meshes)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end