Class: Google::Apis::NetworkservicesV1::ListMulticastConsumerAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListMulticastConsumerAssociationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response message for ListMulticastConsumerAssociations.
Instance Attribute Summary collapse
-
#multicast_consumer_associations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastConsumerAssociation>
The list of multicast consumer associations.
-
#next_page_token ⇒ String
A page token from an earlier query, as returned in
next_page_token. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMulticastConsumerAssociationsResponse
constructor
A new instance of ListMulticastConsumerAssociationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMulticastConsumerAssociationsResponse
Returns a new instance of ListMulticastConsumerAssociationsResponse.
3575 3576 3577 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multicast_consumer_associations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastConsumerAssociation>
The list of multicast consumer associations.
Corresponds to the JSON property multicastConsumerAssociations
3563 3564 3565 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3563 def multicast_consumer_associations @multicast_consumer_associations end |
#next_page_token ⇒ String
A page token from an earlier query, as returned in next_page_token.
Corresponds to the JSON property nextPageToken
3568 3569 3570 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3568 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3573 3574 3575 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3573 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3580 3581 3582 3583 3584 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3580 def update!(**args) @multicast_consumer_associations = args[:multicast_consumer_associations] if args.key?(:multicast_consumer_associations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |