Class: Google::Apis::NetworkservicesV1::ListMulticastGroupConsumerActivationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListMulticastGroupConsumerActivationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response message for ListMulticastGroupConsumerActivations.
Instance Attribute Summary collapse
-
#multicast_group_consumer_activations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation>
The list of multicast group consumer activations.
-
#next_page_token ⇒ String
A page token from an earlier query, as returned in
next_page_token. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMulticastGroupConsumerActivationsResponse
constructor
A new instance of ListMulticastGroupConsumerActivationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMulticastGroupConsumerActivationsResponse
Returns a new instance of ListMulticastGroupConsumerActivationsResponse.
3435 3436 3437 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multicast_group_consumer_activations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation>
The list of multicast group consumer activations.
Corresponds to the JSON property multicastGroupConsumerActivations
3423 3424 3425 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3423 def multicast_group_consumer_activations @multicast_group_consumer_activations end |
#next_page_token ⇒ String
A page token from an earlier query, as returned in next_page_token.
Corresponds to the JSON property nextPageToken
3428 3429 3430 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3428 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3433 3434 3435 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3433 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3440 3441 3442 3443 3444 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3440 def update!(**args) @multicast_group_consumer_activations = args[:multicast_group_consumer_activations] if args.key?(:multicast_group_consumer_activations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |