Class: Google::Apis::NetworkservicesV1::ListProducerExtensionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListProducerExtensions method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListProducerExtensionsResponse

Returns a new instance of ListProducerExtensionsResponse.



4071
4072
4073
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4056
4057
4058
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4056

def next_page_token
  @next_page_token
end

#producer_extensionsArray<Google::Apis::NetworkservicesV1::ProducerExtension>

List of ProducerExtension resources. Corresponds to the JSON property producerExtensions



4061
4062
4063
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4061

def producer_extensions
  @producer_extensions
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. The resource names are in the format: projects/ project/locations/location/producerExtensions/producer_extension`. Corresponds to the JSON propertyunreachable`

Returns:

  • (Array<String>)


4069
4070
4071
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4069

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4076
4077
4078
4079
4080
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4076

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @producer_extensions = args[:producer_extensions] if args.key?(:producer_extensions)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end