Class: Google::Apis::NetworkservicesV1::ListServiceBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListServiceBindings method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServiceBindingsResponse

Returns a new instance of ListServiceBindingsResponse.



3137
3138
3139
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3123
3124
3125
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3123

def next_page_token
  @next_page_token
end

#service_bindingsArray<Google::Apis::NetworkservicesV1::ServiceBinding>

List of ServiceBinding resources. Corresponds to the JSON property serviceBindings



3128
3129
3130
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3128

def service_bindings
  @service_bindings
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3135
3136
3137
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3135

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3142
3143
3144
3145
3146
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3142

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @service_bindings = args[:service_bindings] if args.key?(:service_bindings)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end