Class: Google::Apis::NetworkservicesV1::ListWasmPluginsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListWasmPlugins method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWasmPluginsResponse

Returns a new instance of ListWasmPluginsResponse.



4281
4282
4283
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4267
4268
4269
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4267

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4274
4275
4276
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4274

def unreachable
  @unreachable
end

#wasm_pluginsArray<Google::Apis::NetworkservicesV1::WasmPlugin>

List of WasmPlugin resources. Corresponds to the JSON property wasmPlugins



4279
4280
4281
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4279

def wasm_plugins
  @wasm_plugins
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4286
4287
4288
4289
4290
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4286

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @wasm_plugins = args[:wasm_plugins] if args.key?(:wasm_plugins)
end