Class: Google::Apis::NetworkservicesV1::LoggingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

The configuration for Platform Telemetry logging for Eventarc Advanced resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingConfig

Returns a new instance of LoggingConfig.



3383
3384
3385
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_severityString

Optional. The minimum severity of logs that will be sent to Stackdriver/ Platform Telemetry. Logs at severitiy ≥ this value will be sent, unless it is NONE. Corresponds to the JSON property logSeverity

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3381

def log_severity
  @log_severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3388
3389
3390
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3388

def update!(**args)
  @log_severity = args[:log_severity] if args.key?(:log_severity)
end