Class: Google::Apis::NetworkservicesV1::MulticastConsumerAssociation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Multicast consumer association resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MulticastConsumerAssociation

Returns a new instance of MulticastConsumerAssociation.



4118
4119
4120
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. [Output only] The timestamp when the multicast consumer association was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4054

def create_time
  @create_time
end

#descriptionString

Optional. An optional text description of the multicast consumer association. Corresponds to the JSON property description

Returns:

  • (String)


4059
4060
4061
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4059

def description
  @description
end

#labelsHash<String,String>

Optional. Labels as key-value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4064
4065
4066
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4064

def labels
  @labels
end

#multicast_domain_activationString

Optional. The resource name of the multicast domain activation that is in the same zone as this multicast consumer association. Use the following format: projects/*/locations/*/multicastDomainActivations/*. Corresponds to the JSON property multicastDomainActivation

Returns:

  • (String)


4071
4072
4073
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4071

def multicast_domain_activation
  @multicast_domain_activation
end

#nameString

Identifier. The resource name of the multicast consumer association. Use the following format: projects/*/locations/*/multicastConsumerAssociations/*. Corresponds to the JSON property name

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4077

def name
  @name
end

#networkString

Required. The resource name of the multicast consumer VPC network. Use following format: projects/project/locations/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


4083
4084
4085
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4083

def network
  @network
end

#placement_policyString

Output only. [Output only] A Compute Engine (placement policy)[https://cloud. google.com/compute/docs/instances/placement-policies-overview] that can be used to place virtual machine (VM) instances as multicast consumers close to the multicast infrastructure created for this domain, on a best effort basis. Corresponds to the JSON property placementPolicy

Returns:

  • (String)


4091
4092
4093
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4091

def placement_policy
  @placement_policy
end

#resource_stateString

Output only. [Deprecated] The resource state of the multicast consumer association. Use the state field instead. Corresponds to the JSON property resourceState

Returns:

  • (String)


4097
4098
4099
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4097

def resource_state
  @resource_state
end

#stateGoogle::Apis::NetworkservicesV1::MulticastResourceState

The multicast resource's state. Corresponds to the JSON property state



4102
4103
4104
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4102

def state
  @state
end

#unique_idString

Output only. [Output only] The Google-generated UUID for the resource. This value is unique across all multicast consumer association resources. If a consumer association is deleted and another with the same name is created, the new consumer association is assigned a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4110
4111
4112
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4110

def unique_id
  @unique_id
end

#update_timeString

Output only. [Output only] The timestamp when the Multicast Consumer Association was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4116
4117
4118
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4116

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
4135
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4123

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @multicast_domain_activation = args[:multicast_domain_activation] if args.key?(:multicast_domain_activation)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @placement_policy = args[:placement_policy] if args.key?(:placement_policy)
  @resource_state = args[:resource_state] if args.key?(:resource_state)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end