Class: Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Multicast group consumer activation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MulticastGroupConsumerActivation

Returns a new instance of MulticastGroupConsumerActivation.



4048
4049
4050
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. [Output only] The timestamp when the multicast group consumer activation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3975
3976
3977
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3975

def create_time
  @create_time
end

#descriptionString

Optional. An optional text description of the multicast group consumer activation. Corresponds to the JSON property description

Returns:

  • (String)


3981
3982
3983
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3981

def description
  @description
end

#labelsHash<String,String>

Optional. Labels as key-value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3986
3987
3988
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3986

def labels
  @labels
end

#log_configGoogle::Apis::NetworkservicesV1::MulticastLogConfig

The logging configuration. Corresponds to the JSON property logConfig



3991
3992
3993
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3991

def log_config
  @log_config
end

#multicast_consumer_associationString

Required. The resource name of the multicast consumer association that is in the same zone as this multicast group consumer activation. Use the following format: projects/*/locations/*/multicastConsumerAssociations/*. Corresponds to the JSON property multicastConsumerAssociation

Returns:

  • (String)


3998
3999
4000
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3998

def multicast_consumer_association
  @multicast_consumer_association
end

#multicast_groupString

Optional. The resource name of the multicast group created by the admin in the same zone as this multicast group consumer activation. Use the following format: // projects/*/locations/*/multicastGroups/*. This field is deprecated. Use multicast_group_range_activation instead. Corresponds to the JSON property multicastGroup

Returns:

  • (String)


4006
4007
4008
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4006

def multicast_group
  @multicast_group
end

#multicast_group_range_activationString

Required. The resource name of the multicast group range activation created by the admin in the same zone as this multicast group consumer activation. Use the following format: // projects/*/locations/*/ multicastGroupRangeActivations/*. Corresponds to the JSON property multicastGroupRangeActivation

Returns:

  • (String)


4014
4015
4016
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4014

def multicast_group_range_activation
  @multicast_group_range_activation
end

#nameString

Identifier. The resource name of the multicast group consumer activation. Use the following format: projects/*/locations/*/ multicastGroupConsumerActivations/*. Corresponds to the JSON property name

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4021

def name
  @name
end

#resource_stateString

Output only. [Deprecated] The resource state of the multicast group consumer activation. Use the state field instead. Corresponds to the JSON property resourceState

Returns:

  • (String)


4027
4028
4029
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4027

def resource_state
  @resource_state
end

#stateGoogle::Apis::NetworkservicesV1::MulticastResourceState

The multicast resource's state. Corresponds to the JSON property state



4032
4033
4034
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4032

def state
  @state
end

#unique_idString

Output only. [Output only] The Google-generated UUID for the resource. This value is unique across all multicast group consumer activation resources. If a group consumer activation is deleted and another with the same name is created, the new group consumer activation is assigned a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4040
4041
4042
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4040

def unique_id
  @unique_id
end

#update_timeString

Output only. [Output only] The timestamp when the multicast group consumer activation was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4046
4047
4048
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4046

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4053

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @log_config = args[:log_config] if args.key?(:log_config)
  @multicast_consumer_association = args[:multicast_consumer_association] if args.key?(:multicast_consumer_association)
  @multicast_group = args[:multicast_group] if args.key?(:multicast_group)
  @multicast_group_range_activation = args[:multicast_group_range_activation] if args.key?(:multicast_group_range_activation)
  @name = args[:name] if args.key?(:name)
  @resource_state = args[:resource_state] if args.key?(:resource_state)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end