Class: Google::Apis::NetworkservicesV1::TcpRouteRouteDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Describe the destination for traffic to be routed to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteDestination

Returns a new instance of TcpRouteRouteDestination.



5492
5493
5494
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_nameString

Required. The URL of a BackendService to route traffic to. Corresponds to the JSON property serviceName

Returns:

  • (String)


5477
5478
5479
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5477

def service_name
  @service_name
end

#weightFixnum

Optional. Specifies the proportion of requests forwarded to the backend referenced by the serviceName field. This is computed as: - weight/Sum(weights in this destination list). For non-zero values, there may be some epsilon from the exact proportion defined here depending on the precision an implementation supports. If only one serviceName is specified and it has a weight greater than 0, 100% of the traffic is forwarded to that backend. If weights are specified for any one service name, they need to be specified for all of them. If weights are unspecified for all services, then, traffic is distributed in equal proportions to all of them. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


5490
5491
5492
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5490

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5497
5498
5499
5500
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5497

def update!(**args)
  @service_name = args[:service_name] if args.key?(:service_name)
  @weight = args[:weight] if args.key?(:weight)
end