Class: Google::Apis::NetworkservicesV1::TcpRouteRouteMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. If no routeMatch field is specified, this rule will unconditionally match traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteMatch

Returns a new instance of TcpRouteRouteMatch.



5524
5525
5526
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Required. Must be specified in the CIDR range format. A CIDR range consists of an IP Address and a prefix length to construct the subnet mask. By default, the prefix length is 32 (i.e. matches a single IP address). Only IPV4 addresses are supported. Examples: "10.0.0.1" - matches against this exact IP address. "10.0.0.0/8" - matches against any IP address within the 10.0.0.0 subnet and 255.255.255.0 mask. "0.0.0.0/0" - matches against any IP address'. Corresponds to the JSON property address

Returns:

  • (String)


5517
5518
5519
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5517

def address
  @address
end

#portString

Required. Specifies the destination port to match against. Corresponds to the JSON property port

Returns:

  • (String)


5522
5523
5524
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5522

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5529
5530
5531
5532
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5529

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @port = args[:port] if args.key?(:port)
end