Class: Google::Apis::NetworkservicesV1::TcpRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies how to match traffic and how to route traffic when traffic is matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteRule

Returns a new instance of TcpRouteRouteRule.



4244
4245
4246
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1::TcpRouteRouteAction

The specifications for routing traffic and applying associated policies. Corresponds to the JSON property action



4235
4236
4237
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4235

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1::TcpRouteRouteMatch>

Optional. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. If no routeMatch field is specified, this rule will unconditionally match traffic. Corresponds to the JSON property matches



4242
4243
4244
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4242

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4249
4250
4251
4252
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4249

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end