Class: Google::Apis::NetworkservicesV1::TlsRouteRouteAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

The specifications for routing traffic and applying associated policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteAction

Returns a new instance of TlsRouteRouteAction.



4998
4999
5000
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::NetworkservicesV1::TlsRouteRouteDestination>

Required. The destination services to which traffic should be forwarded. At least one destination service is required. Corresponds to the JSON property destinations



4988
4989
4990
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4988

def destinations
  @destinations
end

#idle_timeoutString

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 1 hour. If set to 0s, the timeout will be disabled. Corresponds to the JSON property idleTimeout

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4996

def idle_timeout
  @idle_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5003
5004
5005
5006
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5003

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout)
end