Class: Google::Apis::NetworkservicesV1::TlsRouteRouteDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Describe the destination for traffic to be routed to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteDestination

Returns a new instance of TlsRouteRouteDestination.



5000
5001
5002
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_nameString

Required. The URL of a BackendService to route traffic to. Corresponds to the JSON property serviceName

Returns:

  • (String)


4990
4991
4992
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4990

def service_name
  @service_name
end

#weightFixnum

Optional. Specifies the proportion of requests forwarded to the backend referenced by the service_name field. This is computed as: - weight/Sum( weights in destinations) Weights in all destinations does not need to sum up to 100. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


4998
4999
5000
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4998

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5005
5006
5007
5008
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5005

def update!(**args)
  @service_name = args[:service_name] if args.key?(:service_name)
  @weight = args[:weight] if args.key?(:weight)
end