Class: Google::Apis::NetworkservicesV1::TlsRouteRouteMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "AND"ed for evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteMatch

Returns a new instance of TlsRouteRouteMatch.



4419
4420
4421
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alpnArray<String>

Optional. ALPN (Application-Layer Protocol Negotiation) to match against. Examples: "http/1.1", "h2". At least one of sni_host and alpn is required. Up to 5 alpns across all matches can be set. Corresponds to the JSON property alpn

Returns:

  • (Array<String>)


4407
4408
4409
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4407

def alpn
  @alpn
end

#sni_hostArray<String>

Optional. SNI (server name indicator) to match against. SNI will be matched against all wildcard domains, i.e. www.example.com will be first matched against www.example.com, then *.example.com, then *.com. Partial wildcards are not supported, and values like *w.example.com are invalid. At least one of sni_host and alpn is required. Up to 100 sni hosts across all matches can be set. Corresponds to the JSON property sniHost

Returns:

  • (Array<String>)


4417
4418
4419
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4417

def sni_host
  @sni_host
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4424
4425
4426
4427
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4424

def update!(**args)
  @alpn = args[:alpn] if args.key?(:alpn)
  @sni_host = args[:sni_host] if args.key?(:sni_host)
end