Class: Google::Apis::NetworkservicesV1::TlsRouteRouteRule
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::TlsRouteRouteRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Specifies how to match traffic and how to route traffic when traffic is matched.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::NetworkservicesV1::TlsRouteRouteAction
The specifications for routing traffic and applying associated policies.
-
#matches ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteMatch>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsRouteRouteRule
constructor
A new instance of TlsRouteRouteRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsRouteRouteRule
Returns a new instance of TlsRouteRouteRule.
5258 5259 5260 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::NetworkservicesV1::TlsRouteRouteAction
The specifications for routing traffic and applying associated policies.
Corresponds to the JSON property action
5249 5250 5251 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5249 def action @action end |
#matches ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteMatch>
Required. RouteMatch defines the predicate used to match requests to a given
action. Multiple match types are "OR"ed for evaluation. Atleast one RouteMatch
must be supplied.
Corresponds to the JSON property matches
5256 5257 5258 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5256 def matches @matches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5263 5264 5265 5266 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5263 def update!(**args) @action = args[:action] if args.key?(:action) @matches = args[:matches] if args.key?(:matches) end |