Class: Google::Apis::NetworkservicesV1::WasmPluginLogConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WasmPluginLogConfig

Returns a new instance of WasmPluginLogConfig.



5944
5945
5946
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Optional. Specifies whether to enable logging for activity by this plugin. Defaults to false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


5921
5922
5923
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5921

def enable
  @enable
end

#min_log_levelString

Optional. Non-empty default. Specifies the lowest level of the plugin logs that are exported to Cloud Logging. This setting relates to the logs generated by using logging statements in your Wasm code. This field is can be set only if logging is enabled for the plugin. If the field is not provided when logging is enabled, it is set to INFO by default. Corresponds to the JSON property minLogLevel

Returns:

  • (String)


5931
5932
5933
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5931

def min_log_level
  @min_log_level
end

#sample_rateFloat

Optional. Non-empty default. Configures the sampling rate of activity logs, where 1.0 means all logged activity is reported and 0.0 means no activity is reported. A floating point value between 0.0 and 1.0 indicates that a percentage of log messages is stored. The default value when logging is enabled is 1.0. The value of the field must be between 0 and 1 ( inclusive). This field can be specified only if logging is enabled for this plugin. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


5942
5943
5944
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5942

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5949
5950
5951
5952
5953
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5949

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @min_log_level = args[:min_log_level] if args.key?(:min_log_level)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end