Class: Google::Apis::NetworkservicesV1::EndpointPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::EndpointPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
EndpointPolicy is a resource that helps apply desired configuration on the endpoints that match specific criteria. For example, this resource can be used to apply "authentication config" an all endpoints that serve on port 8080.
Instance Attribute Summary collapse
-
#authorization_policy ⇒ String
Optional.
-
#client_tls_policy ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoint_matcher ⇒ Google::Apis::NetworkservicesV1::EndpointMatcher
A definition of a matcher that selects endpoints to which the policies should be applied.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#server_tls_policy ⇒ String
Optional.
-
#traffic_port_selector ⇒ Google::Apis::NetworkservicesV1::TrafficPortSelector
Specification of a port-based selector.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndpointPolicy
constructor
A new instance of EndpointPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndpointPolicy
Returns a new instance of EndpointPolicy.
529 530 531 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_policy ⇒ String
Optional. This field specifies the URL of AuthorizationPolicy resource that
applies authorization policies to the inbound traffic at the matched endpoints.
Refer to Authorization. If this field is not specified, authorization is
disabled(no authz checks) for this endpoint.
Corresponds to the JSON property authorizationPolicy
464 465 466 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 464 def @authorization_policy end |
#client_tls_policy ⇒ String
Optional. A URL referring to a ClientTlsPolicy resource. ClientTlsPolicy can
be set to specify the authentication for traffic from the proxy to the actual
endpoints. More specifically, it is applied to the outgoing traffic from the
proxy to the endpoint. This is typically used for sidecar model where the
proxy identifies itself as endpoint to the control plane, with the connection
between sidecar and endpoint requiring authentication. If this field is not
set, authentication is disabled(open). Applicable only when EndpointPolicyType
is SIDECAR_PROXY.
Corresponds to the JSON property clientTlsPolicy
476 477 478 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 476 def client_tls_policy @client_tls_policy end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
481 482 483 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 481 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
486 487 488 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 486 def description @description end |
#endpoint_matcher ⇒ Google::Apis::NetworkservicesV1::EndpointMatcher
A definition of a matcher that selects endpoints to which the policies should
be applied.
Corresponds to the JSON property endpointMatcher
492 493 494 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 492 def endpoint_matcher @endpoint_matcher end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the EndpointPolicy resource.
Corresponds to the JSON property labels
497 498 499 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 497 def labels @labels end |
#name ⇒ String
Identifier. Name of the EndpointPolicy resource. It matches pattern projects/
project/locations/*/endpointPolicies/endpoint_policy`.
Corresponds to the JSON propertyname`
503 504 505 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 503 def name @name end |
#server_tls_policy ⇒ String
Optional. A URL referring to ServerTlsPolicy resource. ServerTlsPolicy is used
to determine the authentication policy to be applied to terminate the inbound
traffic at the identified backends. If this field is not set, authentication
is disabled(open) for this endpoint.
Corresponds to the JSON property serverTlsPolicy
511 512 513 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 511 def server_tls_policy @server_tls_policy end |
#traffic_port_selector ⇒ Google::Apis::NetworkservicesV1::TrafficPortSelector
Specification of a port-based selector.
Corresponds to the JSON property trafficPortSelector
516 517 518 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 516 def traffic_port_selector @traffic_port_selector end |
#type ⇒ String
Required. The type of endpoint policy. This is primarily used to validate the
configuration.
Corresponds to the JSON property type
522 523 524 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 522 def type @type end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
527 528 529 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 527 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 534 def update!(**args) @authorization_policy = args[:authorization_policy] if args.key?(:authorization_policy) @client_tls_policy = args[:client_tls_policy] if args.key?(:client_tls_policy) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoint_matcher = args[:endpoint_matcher] if args.key?(:endpoint_matcher) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy) @traffic_port_selector = args[:traffic_port_selector] if args.key?(:traffic_port_selector) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |