Class: Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionStringMatch
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ExtensionBindingMatchConditionStringMatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Specifies matching logic for string values.
Instance Attribute Summary collapse
-
#contains ⇒ String
Optional.
-
#exact ⇒ String
Optional.
-
#ignore_case ⇒ Boolean
(also: #ignore_case?)
Optional.
-
#prefix ⇒ String
Optional.
-
#suffix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchConditionStringMatch
constructor
A new instance of ExtensionBindingMatchConditionStringMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchConditionStringMatch
Returns a new instance of ExtensionBindingMatchConditionStringMatch.
1206 1207 1208 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains ⇒ String
Optional. The input string must have the substring specified here. Note: empty
contains match is not allowed, please use regex instead. Examples: * abc
matches the value xyz.abc.def
Corresponds to the JSON property contains
1177 1178 1179 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1177 def contains @contains end |
#exact ⇒ String
Optional. The input string must match exactly the string specified here.
Examples: * abc only matches the value abc.
Corresponds to the JSON property exact
1183 1184 1185 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1183 def exact @exact end |
#ignore_case ⇒ Boolean Also known as: ignore_case?
Optional. If true, indicates the exact/prefix/suffix/contains matching should
be case insensitive. For example, the matcher data will match both input
string Data and data if set to true.
Corresponds to the JSON property ignoreCase
1190 1191 1192 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1190 def ignore_case @ignore_case end |
#prefix ⇒ String
Optional. The input string must have the prefix specified here. Note: empty
prefix is not allowed. Examples: * abc matches the value abc.xyz
Corresponds to the JSON property prefix
1197 1198 1199 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1197 def prefix @prefix end |
#suffix ⇒ String
Optional. The input string must have the suffix specified here. Note: empty
prefix is not allowed, please use regex instead. Examples: * abc matches
the value xyz.abc
Corresponds to the JSON property suffix
1204 1205 1206 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1204 def suffix @suffix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1211 def update!(**args) @contains = args[:contains] if args.key?(:contains) @exact = args[:exact] if args.key?(:exact) @ignore_case = args[:ignore_case] if args.key?(:ignore_case) @prefix = args[:prefix] if args.key?(:prefix) @suffix = args[:suffix] if args.key?(:suffix) end |