Class: Google::Apis::NetworkservicesV1::ExtensionChainExtension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

A single extension in the chain to execute for the matching request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionChainExtension

Returns a new instance of ExtensionChainExtension.



788
789
790
# File 'lib/google/apis/networkservices_v1/classes.rb', line 788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityString

Optional. The :authority header in the gRPC request sent from Envoy to the extension service. Required for Callout extensions. This field is not supported for plugin extensions. Setting it results in a validation error. Corresponds to the JSON property authority

Returns:

  • (String)


651
652
653
# File 'lib/google/apis/networkservices_v1/classes.rb', line 651

def authority
  @authority
end

#fail_openBoolean Also known as: fail_open?

Optional. Determines how the proxy behaves if the call to the extension fails or times out. When set to TRUE, request or response processing continues without error. Any subsequent extensions in the extension chain are also executed. When set to FALSE or the default setting of FALSE is used, one of the following happens: * If response headers have not been delivered to the downstream client, a generic 500 error is returned to the client. The error response can be tailored by configuring a custom error response in the load balancer. * If response headers have been delivered, then the HTTP stream to the downstream client is reset. Corresponds to the JSON property failOpen

Returns:

  • (Boolean)


664
665
666
# File 'lib/google/apis/networkservices_v1/classes.rb', line 664

def fail_open
  @fail_open
end

#forward_attributesArray<String>

Optional. List of the Envoy attributes to forward to the extension server. The attributes provided here are included as part of the ProcessingRequest. attributes field (of type map), where the keys are the attribute names. Refer to the documentation for the names of attributes that can be forwarded. If omitted, no attributes are sent. Each element is a string indicating the attribute name. Corresponds to the JSON property forwardAttributes

Returns:

  • (Array<String>)


676
677
678
# File 'lib/google/apis/networkservices_v1/classes.rb', line 676

def forward_attributes
  @forward_attributes
end

#forward_headersArray<String>

Optional. List of the HTTP headers to forward to the extension (from the client or backend). If omitted, all headers are sent. Each element is a string indicating the header name. Corresponds to the JSON property forwardHeaders

Returns:

  • (Array<String>)


683
684
685
# File 'lib/google/apis/networkservices_v1/classes.rb', line 683

def forward_headers
  @forward_headers
end

#metadataHash<String,Object>

Optional. The metadata provided here is included as part of the metadata_context (of type google.protobuf.Struct) in the ProcessingRequest message sent to the extension server. For AuthzExtension resources, the metadata is available under the namespace com.google.authz_extension.. For other types of extensions, the metadata is available under the namespace com. google..... For example: com.google.lb_traffic_extension.lbtrafficextension1. chain1.ext1. The following variables are supported in the metadata: forwarding_rule_id - substituted with the forwarding rule's fully qualified resource name. This field must not be set for plugin extensions. Setting it results in a validation error. You can set metadata at either the resource level or the extension level. The extension level metadata is recommended because you can pass a different set of metadata through each extension to the backend. This field is subject to following limitations: * The total size of the metadata must be less than 1KiB. * The total number of keys in the metadata must be less than 16. * The length of each key must be less than 64 characters. * The length of each value must be less than 1024 characters. * All values must be strings. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


704
705
706
# File 'lib/google/apis/networkservices_v1/classes.rb', line 704

def 
  @metadata
end

#nameString

Optional. The name for this extension. The name is logged as part of the HTTP request logs. The name must conform with RFC-1034, is restricted to lower- cased letters, numbers and hyphens, and can have a maximum length of 63 characters. Additionally, the first character must be a letter and the last a letter or a number. This field is required except for AuthzExtension. Corresponds to the JSON property name

Returns:

  • (String)


713
714
715
# File 'lib/google/apis/networkservices_v1/classes.rb', line 713

def name
  @name
end

#observability_modeBoolean Also known as: observability_mode?

Optional. When set to true, the calls to the extension backend are performed asynchronously, without pausing the processing of the ongoing request. In this mode, only STREAMED (default) body processing is supported. Responses, if any, are ignored. Supported by regional LbTrafficExtension and LbRouteExtension resources. Corresponds to the JSON property observabilityMode

Returns:

  • (Boolean)


722
723
724
# File 'lib/google/apis/networkservices_v1/classes.rb', line 722

def observability_mode
  @observability_mode
end

#request_body_send_modeString

Optional. Configures the send mode for request body processing. The field can only be set if supported_events includes REQUEST_BODY. If supported_events includes REQUEST_BODY, but request_body_send_mode is unset, the default value STREAMED is used. When this field is set to FULL_DUPLEX_STREAMED, supported_events must include both REQUEST_BODY and REQUEST_TRAILERS. This field can be set only for LbTrafficExtension and LbRouteExtension resources, and only when the service field of the extension points to a BackendService. Only FULL_DUPLEX_STREAMED mode is supported for LbRouteExtension resources. Corresponds to the JSON property requestBodySendMode

Returns:

  • (String)


736
737
738
# File 'lib/google/apis/networkservices_v1/classes.rb', line 736

def request_body_send_mode
  @request_body_send_mode
end

#response_body_send_modeString

Optional. Configures the send mode for response processing. If unspecified, the default value STREAMED is used. The field can only be set if supported_events includes RESPONSE_BODY. If supported_events includes RESPONSE_BODY, but response_body_send_mode is unset, the default value STREAMED is used. When this field is set to FULL_DUPLEX_STREAMED, supported_events must include both RESPONSE_BODY and RESPONSE_TRAILERS. This field can be set only for LbTrafficExtension resources, and only when the service field of the extension points to a BackendService. Corresponds to the JSON property responseBodySendMode

Returns:

  • (String)


748
749
750
# File 'lib/google/apis/networkservices_v1/classes.rb', line 748

def response_body_send_mode
  @response_body_send_mode
end

#serviceString

Required. The reference to the service that runs the extension. To configure a callout extension, service must be a fully-qualified reference to a backend service in the format: https://www.googleapis.com/compute/v1/ projects/project/regions/region/backendServices/backendServiceor ` https://www.googleapis.com/compute/v1/projects/`project`/global/ backendServices/`backendService. To configure a plugin extension, service must be a reference to a WasmPlugin resource in the format: projects/project/locations/location/wasmPlugins/plugin or `//networkservices.googleapis.com/projects/`project`/locations/`location`/ wasmPlugins/`wasmPlugin. Plugin extensions are currently supported for the LbTrafficExtension, the LbRouteExtension, and the LbEdgeExtension resources. Corresponds to the JSON property service

Returns:

  • (String)


766
767
768
# File 'lib/google/apis/networkservices_v1/classes.rb', line 766

def service
  @service
end

#supported_eventsArray<String>

Optional. A set of events during request or response processing for which this extension is called. For the LbTrafficExtension resource, this field is required. For the LbRouteExtension resource, this field is optional. If unspecified, REQUEST_HEADERS event is assumed as supported. For the LbEdgeExtension resource, this field is required and must only contain REQUEST_HEADERS event. For the AuthzExtension resource, this field is optional. REQUEST_HEADERS is the only supported event. If unspecified, REQUEST_HEADERS event is assumed as supported. Corresponds to the JSON property supportedEvents

Returns:

  • (Array<String>)


778
779
780
# File 'lib/google/apis/networkservices_v1/classes.rb', line 778

def supported_events
  @supported_events
end

#timeoutString

Optional. Specifies the timeout for each individual message on the stream. The timeout must be between 10-10000 milliseconds. Required for callout extensions. This field is not supported for plugin extensions. Setting it results in a validation error. Corresponds to the JSON property timeout

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/networkservices_v1/classes.rb', line 786

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



793
794
795
796
797
798
799
800
801
802
803
804
805
806
# File 'lib/google/apis/networkservices_v1/classes.rb', line 793

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @fail_open = args[:fail_open] if args.key?(:fail_open)
  @forward_attributes = args[:forward_attributes] if args.key?(:forward_attributes)
  @forward_headers = args[:forward_headers] if args.key?(:forward_headers)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @observability_mode = args[:observability_mode] if args.key?(:observability_mode)
  @request_body_send_mode = args[:request_body_send_mode] if args.key?(:request_body_send_mode)
  @response_body_send_mode = args[:response_body_send_mode] if args.key?(:response_body_send_mode)
  @service = args[:service] if args.key?(:service)
  @supported_events = args[:supported_events] if args.key?(:supported_events)
  @timeout = args[:timeout] if args.key?(:timeout)
end