Class: Google::Apis::NetworkservicesV1::ExtensionChainMatchCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Conditions under which this chain is invoked for a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionChainMatchCondition

Returns a new instance of ExtensionChainMatchCondition.



1227
1228
1229
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cel_expressionString

Required. A Common Expression Language (CEL) expression that is used to match requests for which the extension chain is executed. For more information, see CEL matcher language reference. Corresponds to the JSON property celExpression

Returns:

  • (String)


1225
1226
1227
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1225

def cel_expression
  @cel_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1232
1233
1234
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1232

def update!(**args)
  @cel_expression = args[:cel_expression] if args.key?(:cel_expression)
end