Class: Google::Apis::NetworkservicesV1::ExtensionChainMatchCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Conditions under which this chain is invoked for a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionChainMatchCondition

Returns a new instance of ExtensionChainMatchCondition.



1080
1081
1082
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cel_expressionString

Required. A Common Expression Language (CEL) expression that is used to match requests for which the extension chain is executed. For more information, see CEL matcher language reference. Corresponds to the JSON property celExpression

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1078

def cel_expression
  @cel_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1085
1086
1087
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1085

def update!(**args)
  @cel_expression = args[:cel_expression] if args.key?(:cel_expression)
end