Class: Google::Apis::NetworkservicesV1::Gateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Gateway represents the configuration for a proxy, typically a load balancer. It captures the ip:port over which the services are exposed by the proxy, along with any policy configurations. Routes have reference to to Gateways to dictate how requests should be routed by this Gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Gateway

Returns a new instance of Gateway.



972
973
974
# File 'lib/google/apis/networkservices_v1/classes.rb', line 972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressesArray<String>

Optional. Zero or one IPv4 or IPv6 address on which the Gateway will receive the traffic. When no address is provided, an IP from the subnetwork is allocated This field only applies to gateways of type 'SECURE_WEB_GATEWAY'. Gateways of type 'OPEN_MESH' listen on 0.0.0.0 for IPv4 and :: for IPv6. Corresponds to the JSON property addresses

Returns:

  • (Array<String>)


844
845
846
# File 'lib/google/apis/networkservices_v1/classes.rb', line 844

def addresses
  @addresses
end

#all_portsBoolean Also known as: all_ports?

Optional. If true, the Gateway will listen on all ports. This is mutually exclusive with the ports field. This field only applies to gateways of type ' SECURE_WEB_GATEWAY'. Corresponds to the JSON property allPorts

Returns:

  • (Boolean)


851
852
853
# File 'lib/google/apis/networkservices_v1/classes.rb', line 851

def all_ports
  @all_ports
end

#allow_global_accessBoolean Also known as: allow_global_access?

Optional. If true, the gateway will allow traffic from clients outside of the region where the gateway is located. This field is configurable only for gateways of type SECURE_WEB_GATEWAY. Corresponds to the JSON property allowGlobalAccess

Returns:

  • (Boolean)


859
860
861
# File 'lib/google/apis/networkservices_v1/classes.rb', line 859

def allow_global_access
  @allow_global_access
end

#certificate_urlsArray<String>

Optional. A fully-qualified Certificates URL reference. The proxy presents a Certificate (selected based on SNI) when establishing a TLS connection. This feature only applies to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property certificateUrls

Returns:

  • (Array<String>)


867
868
869
# File 'lib/google/apis/networkservices_v1/classes.rb', line 867

def certificate_urls
  @certificate_urls
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


872
873
874
# File 'lib/google/apis/networkservices_v1/classes.rb', line 872

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


877
878
879
# File 'lib/google/apis/networkservices_v1/classes.rb', line 877

def description
  @description
end

#envoy_headersString

Optional. Determines if envoy will insert internal debug headers into upstream requests. Other Envoy headers may still be injected. By default, envoy will not insert any debug headers. Corresponds to the JSON property envoyHeaders

Returns:

  • (String)


884
885
886
# File 'lib/google/apis/networkservices_v1/classes.rb', line 884

def envoy_headers
  @envoy_headers
end

#gateway_security_policyString

Optional. A fully-qualified GatewaySecurityPolicy URL reference. Defines how a server should apply security policy to inbound (VM to Proxy) initiated connections. For example: projects/*/locations/*/gatewaySecurityPolicies/swg- policy. This policy is specific to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property gatewaySecurityPolicy

Returns:

  • (String)


892
893
894
# File 'lib/google/apis/networkservices_v1/classes.rb', line 892

def gateway_security_policy
  @gateway_security_policy
end

#ip_versionString

Optional. The IP Version that will be used by this gateway. Valid options are IPV4 or IPV6. Default is IPV4. Corresponds to the JSON property ipVersion

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/networkservices_v1/classes.rb', line 898

def ip_version
  @ip_version
end

#labelsHash<String,String>

Optional. Set of label tags associated with the Gateway resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


903
904
905
# File 'lib/google/apis/networkservices_v1/classes.rb', line 903

def labels
  @labels
end

#nameString

Identifier. Name of the Gateway resource. It matches pattern projects/*/ locations/*/gateways/. Corresponds to the JSON property name

Returns:

  • (String)


909
910
911
# File 'lib/google/apis/networkservices_v1/classes.rb', line 909

def name
  @name
end

#networkString

Optional. The relative resource name identifying the VPC network that is using this configuration. For example: projects/*/global/networks/network-1. Currently, this field is specific to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property network

Returns:

  • (String)


916
917
918
# File 'lib/google/apis/networkservices_v1/classes.rb', line 916

def network
  @network
end

#portsArray<Fixnum>

Required. One or more port numbers (1-65535), on which the Gateway will receive traffic. The proxy binds to the specified ports. Gateways of type ' SECURE_WEB_GATEWAY' are limited to 5 ports. Gateways of type 'OPEN_MESH' listen on 0.0.0.0 for IPv4 and :: for IPv6 and support multiple ports. Corresponds to the JSON property ports

Returns:

  • (Array<Fixnum>)


924
925
926
# File 'lib/google/apis/networkservices_v1/classes.rb', line 924

def ports
  @ports
end

#routing_modeString

Optional. The routing mode of the Gateway. This field is configurable only for gateways of type SECURE_WEB_GATEWAY. This field is required for gateways of type SECURE_WEB_GATEWAY. Corresponds to the JSON property routingMode

Returns:

  • (String)


931
932
933
# File 'lib/google/apis/networkservices_v1/classes.rb', line 931

def routing_mode
  @routing_mode
end

#scopeString

Optional. Scope determines how configuration across multiple Gateway instances are merged. The configuration for multiple Gateway instances with the same scope will be merged as presented as a single configuration to the proxy/load balancer. Max length 64 characters. Scope should start with a letter and can only have letters, numbers, hyphens. Corresponds to the JSON property scope

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/networkservices_v1/classes.rb', line 940

def scope
  @scope
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/networkservices_v1/classes.rb', line 945

def self_link
  @self_link
end

#server_tls_policyString

Optional. A fully-qualified ServerTLSPolicy URL reference. Specifies how TLS traffic is terminated. If empty, TLS termination is disabled. Corresponds to the JSON property serverTlsPolicy

Returns:

  • (String)


951
952
953
# File 'lib/google/apis/networkservices_v1/classes.rb', line 951

def server_tls_policy
  @server_tls_policy
end

#subnetworkString

Optional. The relative resource name identifying the subnetwork in which this SWG is allocated. For example: projects/*/regions/us-central1/subnetworks/ network-1 Currently, this field is specific to gateways of type ' SECURE_WEB_GATEWAY". Corresponds to the JSON property subnetwork

Returns:

  • (String)


959
960
961
# File 'lib/google/apis/networkservices_v1/classes.rb', line 959

def subnetwork
  @subnetwork
end

#typeString

Immutable. The type of the customer managed gateway. This field is required. If unspecified, an error is returned. Corresponds to the JSON property type

Returns:

  • (String)


965
966
967
# File 'lib/google/apis/networkservices_v1/classes.rb', line 965

def type
  @type
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


970
971
972
# File 'lib/google/apis/networkservices_v1/classes.rb', line 970

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
# File 'lib/google/apis/networkservices_v1/classes.rb', line 977

def update!(**args)
  @addresses = args[:addresses] if args.key?(:addresses)
  @all_ports = args[:all_ports] if args.key?(:all_ports)
  @allow_global_access = args[:allow_global_access] if args.key?(:allow_global_access)
  @certificate_urls = args[:certificate_urls] if args.key?(:certificate_urls)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @envoy_headers = args[:envoy_headers] if args.key?(:envoy_headers)
  @gateway_security_policy = args[:gateway_security_policy] if args.key?(:gateway_security_policy)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @ports = args[:ports] if args.key?(:ports)
  @routing_mode = args[:routing_mode] if args.key?(:routing_mode)
  @scope = args[:scope] if args.key?(:scope)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end