Class: Google::Apis::NetworkservicesV1::GrpcRouteFaultInjectionPolicyDelay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specification of how client requests are delayed as part of fault injection before being sent to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteFaultInjectionPolicyDelay

Returns a new instance of GrpcRouteFaultInjectionPolicyDelay.



1499
1500
1501
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_delayString

Specify a fixed delay before forwarding the request. Corresponds to the JSON property fixedDelay

Returns:

  • (String)


1491
1492
1493
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1491

def fixed_delay
  @fixed_delay
end

#percentageFixnum

The percentage of traffic on which delay will be injected. The value must be between [0, 100] Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


1497
1498
1499
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1497

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1504
1505
1506
1507
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1504

def update!(**args)
  @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay)
  @percentage = args[:percentage] if args.key?(:percentage)
end