Class: Google::Apis::NetworkservicesV1::GrpcRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Describes how to route traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteRouteRule

Returns a new instance of GrpcRouteRouteRule.



1447
1448
1449
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1::GrpcRouteRouteAction

Specifies how to route matched traffic. Corresponds to the JSON property action



1437
1438
1439
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1437

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1::GrpcRouteRouteMatch>

Optional. Matches define conditions used for matching the rule against incoming gRPC requests. Each match is independent, i.e. this rule will be matched if ANY one of the matches is satisfied. If no matches field is specified, this rule will unconditionally match traffic. Corresponds to the JSON property matches



1445
1446
1447
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1445

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1452
1453
1454
1455
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1452

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end