Class: Google::Apis::NetworkservicesV1::HttpRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

HttpRoute is the resource defining how HTTP traffic should be routed by a Mesh or Gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRoute

Returns a new instance of HttpRoute.



1564
1565
1566
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1494
1495
1496
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1494

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


1499
1500
1501
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1499

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this HttpRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


1506
1507
1508
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1506

def gateways
  @gateways
end

#hostnamesArray<String>

Required. Hostnames define a set of hosts that should match against the HTTP host header to select a HttpRoute to process the request. Hostname is the fully qualified domain name of a network host, as defined by RFC 1123 with the exception that: - IPs are not allowed. - A hostname may be prefixed with a wildcard label (*.). The wildcard label must appear by itself as the first label. Hostname can be "precise" which is a domain name without the terminating dot of a network host (e.g. foo.example.com) or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. *.example. com). Note that as per RFC1035 and RFC1123, a label must consist of lower case alphanumeric characters or '-', and must start and end with an alphanumeric character. No other punctuation is allowed. The routes associated with a Mesh or Gateways must have unique hostnames. If you attempt to attach multiple routes with conflicting hostnames, the configuration will be rejected. For example, while it is acceptable for routes for the hostnames *.foo.bar. com and *.bar.com to be associated with the same Mesh (or Gateways under the same scope), it is not possible to associate two routes both with *.bar. com or both with bar.com. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


1527
1528
1529
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1527

def hostnames
  @hostnames
end

#labelsHash<String,String>

Optional. Set of label tags associated with the HttpRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1532
1533
1534
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1532

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this HttpRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ The attached Mesh should be of a type SIDECAR Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


1540
1541
1542
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1540

def meshes
  @meshes
end

#nameString

Identifier. Name of the HttpRoute resource. It matches pattern projects/*/ locations/*/httpRoutes/http_route_name>. Corresponds to the JSON property name

Returns:

  • (String)


1546
1547
1548
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1546

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1::HttpRouteRouteRule>

Required. Rules that define how traffic is routed and handled. Rules will be matched sequentially based on the RouteMatch specified for the rule. Corresponds to the JSON property rules



1552
1553
1554
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1552

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


1557
1558
1559
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1557

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1562

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1569

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end