Class: Google::Apis::NetworkservicesV1::HttpRouteDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifications of a destination to which the request should be routed to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteDestination

Returns a new instance of HttpRouteDestination.



1686
1687
1688
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_header_modifierGoogle::Apis::NetworkservicesV1::HttpRouteHeaderModifier

The specification for modifying HTTP header in HTTP request and HTTP response. Corresponds to the JSON property requestHeaderModifier



1661
1662
1663
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1661

def request_header_modifier
  @request_header_modifier
end

#response_header_modifierGoogle::Apis::NetworkservicesV1::HttpRouteHeaderModifier

The specification for modifying HTTP header in HTTP request and HTTP response. Corresponds to the JSON property responseHeaderModifier



1666
1667
1668
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1666

def response_header_modifier
  @response_header_modifier
end

#service_nameString

The URL of a BackendService to route traffic to. Corresponds to the JSON property serviceName

Returns:

  • (String)


1671
1672
1673
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1671

def service_name
  @service_name
end

#weightFixnum

Specifies the proportion of requests forwarded to the backend referenced by the serviceName field. This is computed as: - weight/Sum(weights in this destination list). For non-zero values, there may be some epsilon from the exact proportion defined here depending on the precision an implementation supports. If only one serviceName is specified and it has a weight greater than 0, 100% of the traffic is forwarded to that backend. If weights are specified for any one service name, they need to be specified for all of them. If weights are unspecified for all services, then, traffic is distributed in equal proportions to all of them. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


1684
1685
1686
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1684

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1691
1692
1693
1694
1695
1696
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1691

def update!(**args)
  @request_header_modifier = args[:request_header_modifier] if args.key?(:request_header_modifier)
  @response_header_modifier = args[:response_header_modifier] if args.key?(:response_header_modifier)
  @service_name = args[:service_name] if args.key?(:service_name)
  @weight = args[:weight] if args.key?(:weight)
end