Class: Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
The specification for modifying HTTP header in HTTP request and HTTP response.
Instance Attribute Summary collapse
-
#add ⇒ Hash<String,String>
Add the headers with given map where key is the name of the header, value is the value of the header.
-
#remove ⇒ Array<String>
Remove headers (matching by header names) specified in the list.
-
#set ⇒ Hash<String,String>
Completely overwrite/replace the headers with given map where key is the name of the header, value is the value of the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteHeaderModifier
constructor
A new instance of HttpRouteHeaderModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteHeaderModifier
Returns a new instance of HttpRouteHeaderModifier.
1899 1900 1901 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add ⇒ Hash<String,String>
Add the headers with given map where key is the name of the header, value is
the value of the header.
Corresponds to the JSON property add
1886 1887 1888 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1886 def add @add end |
#remove ⇒ Array<String>
Remove headers (matching by header names) specified in the list.
Corresponds to the JSON property remove
1891 1892 1893 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1891 def remove @remove end |
#set ⇒ Hash<String,String>
Completely overwrite/replace the headers with given map where key is the name
of the header, value is the value of the header.
Corresponds to the JSON property set
1897 1898 1899 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1897 def set @set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1904 1905 1906 1907 1908 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 1904 def update!(**args) @add = args[:add] if args.key?(:add) @remove = args[:remove] if args.key?(:remove) @set = args[:set] if args.key?(:set) end |