Class: Google::Apis::NetworkservicesV1::HttpRouteRequestMirrorPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteRequestMirrorPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Specifies the policy on how requests are shadowed to a separate mirrored destination service. The proxy does not wait for responses from the shadow service. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow. Mirroring is currently not supported for Cloud Run destinations.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::NetworkservicesV1::HttpRouteDestination
Specifications of a destination to which the request should be routed to.
-
#mirror_percent ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteRequestMirrorPolicy
constructor
A new instance of HttpRouteRequestMirrorPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteRequestMirrorPolicy
Returns a new instance of HttpRouteRequestMirrorPolicy.
2076 2077 2078 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::NetworkservicesV1::HttpRouteDestination
Specifications of a destination to which the request should be routed to.
Corresponds to the JSON property destination
2068 2069 2070 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2068 def destination @destination end |
#mirror_percent ⇒ Float
Optional. The percentage of requests to get mirrored to the desired
destination.
Corresponds to the JSON property mirrorPercent
2074 2075 2076 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2074 def mirror_percent @mirror_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2081 2082 2083 2084 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2081 def update!(**args) @destination = args[:destination] if args.key?(:destination) @mirror_percent = args[:mirror_percent] if args.key?(:mirror_percent) end |