Class: Google::Apis::NetworkservicesV1::HttpRouteRouteAction
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteRouteAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
The specifications for routing traffic and applying associated policies.
Instance Attribute Summary collapse
-
#cors_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteCorsPolicy
The Specification for allowing client side cross-origin requests.
-
#destinations ⇒ Array<Google::Apis::NetworkservicesV1::HttpRouteDestination>
The destination to which traffic should be forwarded.
-
#direct_response ⇒ Google::Apis::NetworkservicesV1::HttpRouteHttpDirectResponse
Static HTTP response object to be returned.
-
#fault_injection_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteFaultInjectionPolicy
The specification for fault injection introduced into traffic to test the resiliency of clients to destination service failure.
-
#idle_timeout ⇒ String
Optional.
-
#redirect ⇒ Google::Apis::NetworkservicesV1::HttpRouteRedirect
The specification for redirecting traffic.
-
#request_header_modifier ⇒ Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
-
#request_mirror_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteRequestMirrorPolicy
Specifies the policy on how requests are shadowed to a separate mirrored destination service.
-
#response_header_modifier ⇒ Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
-
#retry_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteRetryPolicy
The specifications for retries.
-
#stateful_session_affinity ⇒ Google::Apis::NetworkservicesV1::HttpRouteStatefulSessionAffinityPolicy
The specification for cookie-based stateful session affinity where the date plane supplies a “session cookie” with the name "GSSA" which encodes a specific destination host and each request containing that cookie will be directed to that host as long as the destination host remains up and healthy.
-
#timeout ⇒ String
Specifies the timeout for selected route.
-
#url_rewrite ⇒ Google::Apis::NetworkservicesV1::HttpRouteUrlRewrite
The specification for modifying the URL of the request, prior to forwarding the request to the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteRouteAction
constructor
A new instance of HttpRouteRouteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteRouteAction
Returns a new instance of HttpRouteRouteAction.
2666 2667 2668 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cors_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteCorsPolicy
The Specification for allowing client side cross-origin requests.
Corresponds to the JSON property corsPolicy
2583 2584 2585 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2583 def cors_policy @cors_policy end |
#destinations ⇒ Array<Google::Apis::NetworkservicesV1::HttpRouteDestination>
The destination to which traffic should be forwarded.
Corresponds to the JSON property destinations
2588 2589 2590 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2588 def destinations @destinations end |
#direct_response ⇒ Google::Apis::NetworkservicesV1::HttpRouteHttpDirectResponse
Static HTTP response object to be returned.
Corresponds to the JSON property directResponse
2593 2594 2595 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2593 def direct_response @direct_response end |
#fault_injection_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteFaultInjectionPolicy
The specification for fault injection introduced into traffic to test the
resiliency of clients to destination service failure. As part of fault
injection, when clients send requests to a destination, delays can be
introduced by client proxy on a percentage of requests before sending those
requests to the destination service. Similarly requests can be aborted by
client proxy for a percentage of requests.
Corresponds to the JSON property faultInjectionPolicy
2603 2604 2605 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2603 def fault_injection_policy @fault_injection_policy end |
#idle_timeout ⇒ String
Optional. Specifies the idle timeout for the selected route. The idle timeout
is defined as the period in which there are no bytes sent or received on
either the upstream or downstream connection. If not set, the default idle
timeout is 1 hour. If set to 0s, the timeout will be disabled.
Corresponds to the JSON property idleTimeout
2611 2612 2613 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2611 def idle_timeout @idle_timeout end |
#redirect ⇒ Google::Apis::NetworkservicesV1::HttpRouteRedirect
The specification for redirecting traffic.
Corresponds to the JSON property redirect
2616 2617 2618 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2616 def redirect @redirect end |
#request_header_modifier ⇒ Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
Corresponds to the JSON property requestHeaderModifier
2621 2622 2623 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2621 def request_header_modifier @request_header_modifier end |
#request_mirror_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteRequestMirrorPolicy
Specifies the policy on how requests are shadowed to a separate mirrored
destination service. The proxy does not wait for responses from the shadow
service. Prior to sending traffic to the shadow service, the host/authority
header is suffixed with -shadow. Mirroring is currently not supported for
Cloud Run destinations.
Corresponds to the JSON property requestMirrorPolicy
2630 2631 2632 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2630 def request_mirror_policy @request_mirror_policy end |
#response_header_modifier ⇒ Google::Apis::NetworkservicesV1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
Corresponds to the JSON property responseHeaderModifier
2635 2636 2637 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2635 def response_header_modifier @response_header_modifier end |
#retry_policy ⇒ Google::Apis::NetworkservicesV1::HttpRouteRetryPolicy
The specifications for retries.
Corresponds to the JSON property retryPolicy
2640 2641 2642 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2640 def retry_policy @retry_policy end |
#stateful_session_affinity ⇒ Google::Apis::NetworkservicesV1::HttpRouteStatefulSessionAffinityPolicy
The specification for cookie-based stateful session affinity where the date
plane supplies a “session cookie” with the name "GSSA" which encodes a
specific destination host and each request containing that cookie will be
directed to that host as long as the destination host remains up and healthy.
The gRPC proxyless mesh library or sidecar proxy will manage the session
cookie but the client application code is responsible for copying the cookie
from each RPC in the session to the next.
Corresponds to the JSON property statefulSessionAffinity
2651 2652 2653 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2651 def stateful_session_affinity @stateful_session_affinity end |
#timeout ⇒ String
Specifies the timeout for selected route. Timeout is computed from the time
the request has been fully processed (i.e. end of stream) up until the
response has been completely processed. Timeout includes all retries.
Corresponds to the JSON property timeout
2658 2659 2660 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2658 def timeout @timeout end |
#url_rewrite ⇒ Google::Apis::NetworkservicesV1::HttpRouteUrlRewrite
The specification for modifying the URL of the request, prior to forwarding
the request to the destination.
Corresponds to the JSON property urlRewrite
2664 2665 2666 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2664 def url_rewrite @url_rewrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2671 def update!(**args) @cors_policy = args[:cors_policy] if args.key?(:cors_policy) @destinations = args[:destinations] if args.key?(:destinations) @direct_response = args[:direct_response] if args.key?(:direct_response) @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy) @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout) @redirect = args[:redirect] if args.key?(:redirect) @request_header_modifier = args[:request_header_modifier] if args.key?(:request_header_modifier) @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy) @response_header_modifier = args[:response_header_modifier] if args.key?(:response_header_modifier) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @stateful_session_affinity = args[:stateful_session_affinity] if args.key?(:stateful_session_affinity) @timeout = args[:timeout] if args.key?(:timeout) @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite) end |