Class: Google::Apis::NetworkservicesV1::HttpRouteRouteRule
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteRouteRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Specifies how to match traffic and how to route traffic when traffic is matched.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::NetworkservicesV1::HttpRouteRouteAction
The specifications for routing traffic and applying associated policies.
-
#matches ⇒ Array<Google::Apis::NetworkservicesV1::HttpRouteRouteMatch>
A list of matches define conditions used for matching the rule against incoming HTTP requests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteRouteRule
constructor
A new instance of HttpRouteRouteRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteRouteRule
Returns a new instance of HttpRouteRouteRule.
3128 3129 3130 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::NetworkservicesV1::HttpRouteRouteAction
The specifications for routing traffic and applying associated policies.
Corresponds to the JSON property action
3116 3117 3118 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3116 def action @action end |
#matches ⇒ Array<Google::Apis::NetworkservicesV1::HttpRouteRouteMatch>
A list of matches define conditions used for matching the rule against
incoming HTTP requests. Each match is independent, i.e. this rule will be
matched if ANY one of the matches is satisfied. If no matches field is
specified, this rule will unconditionally match traffic. If a default rule is
desired to be configured, add a rule with no matches specified to the end of
the rules list.
Corresponds to the JSON property matches
3126 3127 3128 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3126 def matches @matches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3133 3134 3135 3136 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3133 def update!(**args) @action = args[:action] if args.key?(:action) @matches = args[:matches] if args.key?(:matches) end |