Class: Google::Apis::NetworkservicesV1::HttpRouteStatefulSessionAffinityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::HttpRouteStatefulSessionAffinityPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
The specification for cookie-based stateful session affinity where the date plane supplies a “session cookie” with the name "GSSA" which encodes a specific destination host and each request containing that cookie will be directed to that host as long as the destination host remains up and healthy. The gRPC proxyless mesh library or sidecar proxy will manage the session cookie but the client application code is responsible for copying the cookie from each RPC in the session to the next.
Instance Attribute Summary collapse
-
#cookie_ttl ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteStatefulSessionAffinityPolicy
constructor
A new instance of HttpRouteStatefulSessionAffinityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteStatefulSessionAffinityPolicy
Returns a new instance of HttpRouteStatefulSessionAffinityPolicy.
2636 2637 2638 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cookie_ttl ⇒ String
Required. The cookie TTL value for the Set-Cookie header generated by the data
plane. The lifetime of the cookie may be set to a value from 0 to 86400
seconds (24 hours) inclusive. Set this to 0s to use a session cookie and
disable cookie expiration.
Corresponds to the JSON property cookieTtl
2634 2635 2636 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2634 def @cookie_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2641 2642 2643 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2641 def update!(**args) @cookie_ttl = args[:cookie_ttl] if args.key?(:cookie_ttl) end |