Class: Google::Apis::NetworkservicesV1::ListGatewayRouteViewsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListGatewayRouteViews method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewayRouteViewsResponse

Returns a new instance of ListGatewayRouteViewsResponse.



2738
2739
2740
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gateway_route_viewsArray<Google::Apis::NetworkservicesV1::GatewayRouteView>

List of GatewayRouteView resources. Corresponds to the JSON property gatewayRouteViews



2723
2724
2725
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2723

def gateway_route_views
  @gateway_route_views
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2729
2730
2731
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2729

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2736
2737
2738
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2736

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2743
2744
2745
2746
2747
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2743

def update!(**args)
  @gateway_route_views = args[:gateway_route_views] if args.key?(:gateway_route_views)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end