Class: Google::Apis::NetworkservicesV1::ListGatewaysResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListGateways method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewaysResponse

Returns a new instance of ListGatewaysResponse.



3116
3117
3118
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gatewaysArray<Google::Apis::NetworkservicesV1::Gateway>

List of Gateway resources. Corresponds to the JSON property gateways



3102
3103
3104
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3102

def gateways
  @gateways
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3109
3110
3111
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3109

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3114
3115
3116
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3114

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3121
3122
3123
3124
3125
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3121

def update!(**args)
  @gateways = args[:gateways] if args.key?(:gateways)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end