Class: Google::Apis::NetworkservicesV1::ListGrpcRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListGrpcRoutes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGrpcRoutesResponse

Returns a new instance of ListGrpcRoutesResponse.



2806
2807
2808
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grpc_routesArray<Google::Apis::NetworkservicesV1::GrpcRoute>

List of GrpcRoute resources. Corresponds to the JSON property grpcRoutes



2790
2791
2792
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2790

def grpc_routes
  @grpc_routes
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2797
2798
2799
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2797

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2804
2805
2806
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2804

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2811
2812
2813
2814
2815
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2811

def update!(**args)
  @grpc_routes = args[:grpc_routes] if args.key?(:grpc_routes)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end