Class: Google::Apis::NetworkservicesV1::ListHttpRoutesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListHttpRoutesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListHttpRoutes method.
Instance Attribute Summary collapse
-
#http_routes ⇒ Array<Google::Apis::NetworkservicesV1::HttpRoute>
List of HttpRoute resources.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHttpRoutesResponse
constructor
A new instance of ListHttpRoutesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHttpRoutesResponse
Returns a new instance of ListHttpRoutesResponse.
2841 2842 2843 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_routes ⇒ Array<Google::Apis::NetworkservicesV1::HttpRoute>
List of HttpRoute resources.
Corresponds to the JSON property httpRoutes
2825 2826 2827 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2825 def http_routes @http_routes end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
2832 2833 2834 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2832 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when attempting to
list all resources across all supported locations.
Corresponds to the JSON property unreachable
2839 2840 2841 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2839 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2846 2847 2848 2849 2850 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 2846 def update!(**args) @http_routes = args[:http_routes] if args.key?(:http_routes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |