Class: Google::Apis::NetworkservicesV1::ListMulticastConsumerAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListMulticastConsumerAssociationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response message for ListMulticastConsumerAssociations.
Instance Attribute Summary collapse
-
#multicast_consumer_associations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastConsumerAssociation>
The list of multicast consumer associations.
-
#next_page_token ⇒ String
A page token from an earlier query, as returned in
next_page_token. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMulticastConsumerAssociationsResponse
constructor
A new instance of ListMulticastConsumerAssociationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMulticastConsumerAssociationsResponse
Returns a new instance of ListMulticastConsumerAssociationsResponse.
3378 3379 3380 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multicast_consumer_associations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastConsumerAssociation>
The list of multicast consumer associations.
Corresponds to the JSON property multicastConsumerAssociations
3366 3367 3368 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3366 def multicast_consumer_associations @multicast_consumer_associations end |
#next_page_token ⇒ String
A page token from an earlier query, as returned in next_page_token.
Corresponds to the JSON property nextPageToken
3371 3372 3373 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3371 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3376 3377 3378 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3376 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3383 3384 3385 3386 3387 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3383 def update!(**args) @multicast_consumer_associations = args[:multicast_consumer_associations] if args.key?(:multicast_consumer_associations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |