Class: Google::Apis::NetworkservicesV1::ListMulticastGroupConsumerActivationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListMulticastGroupConsumerActivationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response message for ListMulticastGroupConsumerActivations.
Instance Attribute Summary collapse
-
#multicast_group_consumer_activations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation>
The list of multicast group consumer activations.
-
#next_page_token ⇒ String
A page token from an earlier query, as returned in
next_page_token. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMulticastGroupConsumerActivationsResponse
constructor
A new instance of ListMulticastGroupConsumerActivationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMulticastGroupConsumerActivationsResponse
Returns a new instance of ListMulticastGroupConsumerActivationsResponse.
3409 3410 3411 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multicast_group_consumer_activations ⇒ Array<Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation>
The list of multicast group consumer activations.
Corresponds to the JSON property multicastGroupConsumerActivations
3397 3398 3399 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3397 def multicast_group_consumer_activations @multicast_group_consumer_activations end |
#next_page_token ⇒ String
A page token from an earlier query, as returned in next_page_token.
Corresponds to the JSON property nextPageToken
3402 3403 3404 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3402 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3407 3408 3409 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3407 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3414 3415 3416 3417 3418 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3414 def update!(**args) @multicast_group_consumer_activations = args[:multicast_group_consumer_activations] if args.key?(:multicast_group_consumer_activations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |