Class: Google::Apis::NetworkservicesV1::ListServiceBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListServiceBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListServiceBindings method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#service_bindings ⇒ Array<Google::Apis::NetworkservicesV1::ServiceBinding>
List of ServiceBinding resources.
-
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServiceBindingsResponse
constructor
A new instance of ListServiceBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServiceBindingsResponse
Returns a new instance of ListServiceBindingsResponse.
3097 3098 3099 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3083 3084 3085 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3083 def next_page_token @next_page_token end |
#service_bindings ⇒ Array<Google::Apis::NetworkservicesV1::ServiceBinding>
List of ServiceBinding resources.
Corresponds to the JSON property serviceBindings
3088 3089 3090 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3088 def service_bindings @service_bindings end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request attempts to list all
resources across all supported locations, while some locations are temporarily
unavailable.
Corresponds to the JSON property unreachable
3095 3096 3097 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3095 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3102 3103 3104 3105 3106 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3102 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @service_bindings = args[:service_bindings] if args.key?(:service_bindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |