Class: Google::Apis::NetworkservicesV1::ListTcpRoutesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListTcpRoutesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListTcpRoutes method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#tcp_routes ⇒ Array<Google::Apis::NetworkservicesV1::TcpRoute>
List of TcpRoute resources.
-
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTcpRoutesResponse
constructor
A new instance of ListTcpRoutesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTcpRoutesResponse
Returns a new instance of ListTcpRoutesResponse.
3167 3168 3169 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3153 3154 3155 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3153 def next_page_token @next_page_token end |
#tcp_routes ⇒ Array<Google::Apis::NetworkservicesV1::TcpRoute>
List of TcpRoute resources.
Corresponds to the JSON property tcpRoutes
3158 3159 3160 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3158 def tcp_routes @tcp_routes end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when attempting to
list all resources across all supported locations.
Corresponds to the JSON property unreachable
3165 3166 3167 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3165 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3172 3173 3174 3175 3176 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3172 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tcp_routes = args[:tcp_routes] if args.key?(:tcp_routes) @unreachable = args[:unreachable] if args.key?(:unreachable) end |