Class: Google::Apis::NetworkservicesV1::ListWasmPluginVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListWasmPluginVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListWasmPluginVersions method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
-
#wasm_plugin_versions ⇒ Array<Google::Apis::NetworkservicesV1::WasmPluginVersion>
List of
WasmPluginVersionresources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWasmPluginVersionsResponse
constructor
A new instance of ListWasmPluginVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWasmPluginVersionsResponse
Returns a new instance of ListWasmPluginVersionsResponse.
3618 3619 3620 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3604 3605 3606 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3604 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request attempts to list all
resources across all supported locations, while some locations are temporarily
unavailable.
Corresponds to the JSON property unreachable
3611 3612 3613 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3611 def unreachable @unreachable end |
#wasm_plugin_versions ⇒ Array<Google::Apis::NetworkservicesV1::WasmPluginVersion>
List of WasmPluginVersion resources.
Corresponds to the JSON property wasmPluginVersions
3616 3617 3618 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3616 def wasm_plugin_versions @wasm_plugin_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3623 3624 3625 3626 3627 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3623 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @wasm_plugin_versions = args[:wasm_plugin_versions] if args.key?(:wasm_plugin_versions) end |