Class: Google::Apis::NetworkservicesV1::ListWasmPluginVersionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Response returned by the ListWasmPluginVersions method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWasmPluginVersionsResponse

Returns a new instance of ListWasmPluginVersionsResponse.



3277
3278
3279
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3263
3264
3265
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3263

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3270
3271
3272
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3270

def unreachable
  @unreachable
end

#wasm_plugin_versionsArray<Google::Apis::NetworkservicesV1::WasmPluginVersion>

List of WasmPluginVersion resources. Corresponds to the JSON property wasmPluginVersions



3275
3276
3277
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3275

def wasm_plugin_versions
  @wasm_plugin_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3282
3283
3284
3285
3286
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3282

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @wasm_plugin_versions = args[:wasm_plugin_versions] if args.key?(:wasm_plugin_versions)
end