Class: Google::Apis::NetworkservicesV1::ListWasmPluginsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ListWasmPluginsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Response returned by the ListWasmPlugins method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
-
#wasm_plugins ⇒ Array<Google::Apis::NetworkservicesV1::WasmPlugin>
List of
WasmPluginresources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWasmPluginsResponse
constructor
A new instance of ListWasmPluginsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWasmPluginsResponse
Returns a new instance of ListWasmPluginsResponse.
3850 3851 3852 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3836 3837 3838 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3836 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request attempts to list all
resources across all supported locations, while some locations are temporarily
unavailable.
Corresponds to the JSON property unreachable
3843 3844 3845 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3843 def unreachable @unreachable end |
#wasm_plugins ⇒ Array<Google::Apis::NetworkservicesV1::WasmPlugin>
List of WasmPlugin resources.
Corresponds to the JSON property wasmPlugins
3848 3849 3850 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3848 def wasm_plugins @wasm_plugins end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3855 3856 3857 3858 3859 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3855 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @wasm_plugins = args[:wasm_plugins] if args.key?(:wasm_plugins) end |