Class: Google::Apis::NetworkservicesV1::MulticastConsumerAssociation
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::MulticastConsumerAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Multicast consumer association resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#multicast_domain_activation ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Required.
-
#placement_policy ⇒ String
Output only.
-
#resource_state ⇒ String
Output only.
-
#state ⇒ Google::Apis::NetworkservicesV1::MulticastResourceState
The multicast resource's state.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticastConsumerAssociation
constructor
A new instance of MulticastConsumerAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticastConsumerAssociation
Returns a new instance of MulticastConsumerAssociation.
4118 4119 4120 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. [Output only] The timestamp when the multicast consumer
association was created.
Corresponds to the JSON property createTime
4054 4055 4056 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4054 def create_time @create_time end |
#description ⇒ String
Optional. An optional text description of the multicast consumer association.
Corresponds to the JSON property description
4059 4060 4061 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4059 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels as key-value pairs
Corresponds to the JSON property labels
4064 4065 4066 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4064 def labels @labels end |
#multicast_domain_activation ⇒ String
Optional. The resource name of the multicast domain activation that is in the
same zone as this multicast consumer association. Use the following format:
projects/*/locations/*/multicastDomainActivations/*.
Corresponds to the JSON property multicastDomainActivation
4071 4072 4073 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4071 def multicast_domain_activation @multicast_domain_activation end |
#name ⇒ String
Identifier. The resource name of the multicast consumer association. Use the
following format: projects/*/locations/*/multicastConsumerAssociations/*.
Corresponds to the JSON property name
4077 4078 4079 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4077 def name @name end |
#network ⇒ String
Required. The resource name of the multicast consumer VPC network. Use
following format: projects/project/locations/global/networks/network`.
Corresponds to the JSON propertynetwork`
4083 4084 4085 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4083 def network @network end |
#placement_policy ⇒ String
Output only. [Output only] A Compute Engine (placement policy)[https://cloud.
google.com/compute/docs/instances/placement-policies-overview] that can be
used to place virtual machine (VM) instances as multicast consumers close to
the multicast infrastructure created for this domain, on a best effort basis.
Corresponds to the JSON property placementPolicy
4091 4092 4093 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4091 def placement_policy @placement_policy end |
#resource_state ⇒ String
Output only. [Deprecated] The resource state of the multicast consumer
association. Use the state field instead.
Corresponds to the JSON property resourceState
4097 4098 4099 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4097 def resource_state @resource_state end |
#state ⇒ Google::Apis::NetworkservicesV1::MulticastResourceState
The multicast resource's state.
Corresponds to the JSON property state
4102 4103 4104 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4102 def state @state end |
#unique_id ⇒ String
Output only. [Output only] The Google-generated UUID for the resource. This
value is unique across all multicast consumer association resources. If a
consumer association is deleted and another with the same name is created, the
new consumer association is assigned a different unique_id.
Corresponds to the JSON property uniqueId
4110 4111 4112 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4110 def unique_id @unique_id end |
#update_time ⇒ String
Output only. [Output only] The timestamp when the Multicast Consumer
Association was most recently updated.
Corresponds to the JSON property updateTime
4116 4117 4118 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4116 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4123 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @multicast_domain_activation = args[:multicast_domain_activation] if args.key?(:multicast_domain_activation) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @placement_policy = args[:placement_policy] if args.key?(:placement_policy) @resource_state = args[:resource_state] if args.key?(:resource_state) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |