Class: Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::MulticastGroupConsumerActivation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Multicast group consumer activation resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#log_config ⇒ Google::Apis::NetworkservicesV1::MulticastLogConfig
The logging configuration.
-
#multicast_consumer_association ⇒ String
Required.
-
#multicast_group ⇒ String
Optional.
-
#multicast_group_range_activation ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#resource_state ⇒ String
Output only.
-
#state ⇒ Google::Apis::NetworkservicesV1::MulticastResourceState
The multicast resource's state.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticastGroupConsumerActivation
constructor
A new instance of MulticastGroupConsumerActivation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticastGroupConsumerActivation
Returns a new instance of MulticastGroupConsumerActivation.
4022 4023 4024 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. [Output only] The timestamp when the multicast group consumer
activation was created.
Corresponds to the JSON property createTime
3949 3950 3951 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3949 def create_time @create_time end |
#description ⇒ String
Optional. An optional text description of the multicast group consumer
activation.
Corresponds to the JSON property description
3955 3956 3957 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3955 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels as key-value pairs
Corresponds to the JSON property labels
3960 3961 3962 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3960 def labels @labels end |
#log_config ⇒ Google::Apis::NetworkservicesV1::MulticastLogConfig
The logging configuration.
Corresponds to the JSON property logConfig
3965 3966 3967 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3965 def log_config @log_config end |
#multicast_consumer_association ⇒ String
Required. The resource name of the multicast consumer association that is in
the same zone as this multicast group consumer activation. Use the following
format: projects/*/locations/*/multicastConsumerAssociations/*.
Corresponds to the JSON property multicastConsumerAssociation
3972 3973 3974 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3972 def multicast_consumer_association @multicast_consumer_association end |
#multicast_group ⇒ String
Optional. The resource name of the multicast group created by the admin in the
same zone as this multicast group consumer activation. Use the following
format: // projects/*/locations/*/multicastGroups/*. This field is
deprecated. Use multicast_group_range_activation instead.
Corresponds to the JSON property multicastGroup
3980 3981 3982 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3980 def multicast_group @multicast_group end |
#multicast_group_range_activation ⇒ String
Required. The resource name of the multicast group range activation created by
the admin in the same zone as this multicast group consumer activation. Use
the following format: // projects/*/locations/*/
multicastGroupRangeActivations/*.
Corresponds to the JSON property multicastGroupRangeActivation
3988 3989 3990 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3988 def multicast_group_range_activation @multicast_group_range_activation end |
#name ⇒ String
Identifier. The resource name of the multicast group consumer activation. Use
the following format: projects/*/locations/*/
multicastGroupConsumerActivations/*.
Corresponds to the JSON property name
3995 3996 3997 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3995 def name @name end |
#resource_state ⇒ String
Output only. [Deprecated] The resource state of the multicast group consumer
activation. Use the state field instead.
Corresponds to the JSON property resourceState
4001 4002 4003 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4001 def resource_state @resource_state end |
#state ⇒ Google::Apis::NetworkservicesV1::MulticastResourceState
The multicast resource's state.
Corresponds to the JSON property state
4006 4007 4008 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4006 def state @state end |
#unique_id ⇒ String
Output only. [Output only] The Google-generated UUID for the resource. This
value is unique across all multicast group consumer activation resources. If a
group consumer activation is deleted and another with the same name is created,
the new group consumer activation is assigned a different unique_id.
Corresponds to the JSON property uniqueId
4014 4015 4016 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4014 def unique_id @unique_id end |
#update_time ⇒ String
Output only. [Output only] The timestamp when the multicast group consumer
activation was most recently updated.
Corresponds to the JSON property updateTime
4020 4021 4022 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4020 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4027 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @log_config = args[:log_config] if args.key?(:log_config) @multicast_consumer_association = args[:multicast_consumer_association] if args.key?(:multicast_consumer_association) @multicast_group = args[:multicast_group] if args.key?(:multicast_group) @multicast_group_range_activation = args[:multicast_group_range_activation] if args.key?(:multicast_group_range_activation) @name = args[:name] if args.key?(:name) @resource_state = args[:resource_state] if args.key?(:resource_state) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |