Class: Google::Apis::NetworkservicesV1::ProducerExtension
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ProducerExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
ProducerExtension is a resource representing producer defined configuration
for their service extension.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#extension_settings ⇒ Google::Apis::NetworkservicesV1::ProducerExtensionExtensionSettings
The configuration for the service that this
ProducerExtensionoffers. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#phase ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProducerExtension
constructor
A new instance of ProducerExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProducerExtension
Returns a new instance of ProducerExtension.
4977 4978 4979 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4934 4935 4936 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4934 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
4939 4940 4941 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4939 def description @description end |
#etag ⇒ String
Optional. Etag of the resource. If this is provided, it must match the server'
s etag. If the provided etag does not match the server's etag, the request
will fail with a 409 ABORTED error.
Corresponds to the JSON property etag
4946 4947 4948 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4946 def etag @etag end |
#extension_settings ⇒ Google::Apis::NetworkservicesV1::ProducerExtensionExtensionSettings
The configuration for the service that this ProducerExtension offers.
Corresponds to the JSON property extensionSettings
4951 4952 4953 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4951 def extension_settings @extension_settings end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the ProducerExtension resource. The
format must comply with [the following requirements]((https://cloud.google.com/
compute/docs/labeling-resources#requirements).
Corresponds to the JSON property labels
4958 4959 4960 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4958 def labels @labels end |
#name ⇒ String
Identifier. Name of the ProducerExtension resource in the following format:
projects/project/locations/location/producerExtensions/producer_extension
.
Corresponds to the JSON property name
4965 4966 4967 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4965 def name @name end |
#phase ⇒ String
Required. The phase in which this ProducerExtension should execute.
Corresponds to the JSON property phase
4970 4971 4972 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4970 def phase @phase end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4975 4976 4977 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4975 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4982 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @extension_settings = args[:extension_settings] if args.key?(:extension_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @update_time = args[:update_time] if args.key?(:update_time) end |