Class: Google::Apis::NetworkservicesV1::ServiceBinding
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ServiceBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#service ⇒ String
Optional.
-
#service_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceBinding
constructor
A new instance of ServiceBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceBinding
Returns a new instance of ServiceBinding.
5101 5102 5103 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
5062 5063 5064 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5062 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
5067 5068 5069 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5067 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the ServiceBinding resource.
Corresponds to the JSON property labels
5072 5073 5074 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5072 def labels @labels end |
#name ⇒ String
Identifier. Name of the ServiceBinding resource. It matches pattern projects/*
/locations/*/serviceBindings/.
Corresponds to the JSON property name
5078 5079 5080 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5078 def name @name end |
#service ⇒ String
Optional. The full Service Directory Service name of the format projects/*/
locations/*/namespaces/*/services/*. This field is for Service Directory
integration which will be deprecated soon.
Corresponds to the JSON property service
5085 5086 5087 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5085 def service @service end |
#service_id ⇒ String
Output only. The unique identifier of the Service Directory Service against
which the ServiceBinding resource is validated. This is populated when the
Service Binding resource is used in another resource (like Backend Service).
This is of the UUID4 format. This field is for Service Directory integration
which will be deprecated soon.
Corresponds to the JSON property serviceId
5094 5095 5096 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5094 def service_id @service_id end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
5099 5100 5101 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5099 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5106 5107 5108 5109 5110 5111 5112 5113 5114 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5106 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service = args[:service] if args.key?(:service) @service_id = args[:service_id] if args.key?(:service_id) @update_time = args[:update_time] if args.key?(:update_time) end |