Class: Google::Apis::NetworkservicesV1::ServiceBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceBinding

Returns a new instance of ServiceBinding.



4564
4565
4566
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4525
4526
4527
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4525

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4530
4531
4532
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4530

def description
  @description
end

#labelsHash<String,String>

Optional. Set of label tags associated with the ServiceBinding resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4535
4536
4537
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4535

def labels
  @labels
end

#nameString

Identifier. Name of the ServiceBinding resource. It matches pattern projects/* /locations/*/serviceBindings/. Corresponds to the JSON property name

Returns:

  • (String)


4541
4542
4543
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4541

def name
  @name
end

#serviceString

Optional. The full Service Directory Service name of the format projects/*/ locations/*/namespaces/*/services/*. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property service

Returns:

  • (String)


4548
4549
4550
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4548

def service
  @service
end

#service_idString

Output only. The unique identifier of the Service Directory Service against which the ServiceBinding resource is validated. This is populated when the Service Binding resource is used in another resource (like Backend Service). This is of the UUID4 format. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property serviceId

Returns:

  • (String)


4557
4558
4559
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4557

def service_id
  @service_id
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4562
4563
4564
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4562

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4569
4570
4571
4572
4573
4574
4575
4576
4577
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4569

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @service_id = args[:service_id] if args.key?(:service_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end