Class: Google::Apis::NetworkservicesV1::ServiceBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceBinding

Returns a new instance of ServiceBinding.



4367
4368
4369
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4328
4329
4330
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4328

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4333
4334
4335
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4333

def description
  @description
end

#labelsHash<String,String>

Optional. Set of label tags associated with the ServiceBinding resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4338
4339
4340
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4338

def labels
  @labels
end

#nameString

Identifier. Name of the ServiceBinding resource. It matches pattern projects/* /locations/*/serviceBindings/. Corresponds to the JSON property name

Returns:

  • (String)


4344
4345
4346
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4344

def name
  @name
end

#serviceString

Optional. The full Service Directory Service name of the format projects/*/ locations/*/namespaces/*/services/*. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property service

Returns:

  • (String)


4351
4352
4353
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4351

def service
  @service
end

#service_idString

Output only. The unique identifier of the Service Directory Service against which the ServiceBinding resource is validated. This is populated when the Service Binding resource is used in another resource (like Backend Service). This is of the UUID4 format. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property serviceId

Returns:

  • (String)


4360
4361
4362
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4360

def service_id
  @service_id
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4365
4366
4367
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4365

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4372
4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4372

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @service_id = args[:service_id] if args.key?(:service_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end