Class: Google::Apis::NetworkservicesV1::ServiceBinding
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ServiceBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#service ⇒ String
Optional.
-
#service_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceBinding
constructor
A new instance of ServiceBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceBinding
Returns a new instance of ServiceBinding.
3793 3794 3795 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
3754 3755 3756 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3754 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
3759 3760 3761 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3759 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the ServiceBinding resource.
Corresponds to the JSON property labels
3764 3765 3766 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3764 def labels @labels end |
#name ⇒ String
Identifier. Name of the ServiceBinding resource. It matches pattern projects/*
/locations/*/serviceBindings/.
Corresponds to the JSON property name
3770 3771 3772 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3770 def name @name end |
#service ⇒ String
Optional. The full Service Directory Service name of the format projects/*/
locations/*/namespaces/*/services/*. This field is for Service Directory
integration which will be deprecated soon.
Corresponds to the JSON property service
3777 3778 3779 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3777 def service @service end |
#service_id ⇒ String
Output only. The unique identifier of the Service Directory Service against
which the ServiceBinding resource is validated. This is populated when the
Service Binding resource is used in another resource (like Backend Service).
This is of the UUID4 format. This field is for Service Directory integration
which will be deprecated soon.
Corresponds to the JSON property serviceId
3786 3787 3788 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3786 def service_id @service_id end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
3791 3792 3793 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3791 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3798 3799 3800 3801 3802 3803 3804 3805 3806 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3798 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service = args[:service] if args.key?(:service) @service_id = args[:service_id] if args.key?(:service_id) @update_time = args[:update_time] if args.key?(:update_time) end |