Class: Google::Apis::NetworkservicesV1::ServiceLbPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::ServiceLbPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
ServiceLbPolicy holds global load balancing and traffic distribution configuration that can be applied to a BackendService.
Instance Attribute Summary collapse
-
#auto_capacity_drain ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyAutoCapacityDrain
Option to specify if an unhealthy IG/NEG should be considered for global load balancing and traffic routing.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#failover_config ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyFailoverConfig
Option to specify health based failover behavior.
-
#isolation_config ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyIsolationConfig
Configuration to provide isolation support for the associated Backend Service.
-
#labels ⇒ Hash<String,String>
Optional.
-
#load_balancing_algorithm ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceLbPolicy
constructor
A new instance of ServiceLbPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceLbPolicy
Returns a new instance of ServiceLbPolicy.
3823 3824 3825 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_capacity_drain ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyAutoCapacityDrain
Option to specify if an unhealthy IG/NEG should be considered for global load
balancing and traffic routing.
Corresponds to the JSON property autoCapacityDrain
3778 3779 3780 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3778 def auto_capacity_drain @auto_capacity_drain end |
#create_time ⇒ String
Output only. The timestamp when this resource was created.
Corresponds to the JSON property createTime
3783 3784 3785 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3783 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
3788 3789 3790 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3788 def description @description end |
#failover_config ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyFailoverConfig
Option to specify health based failover behavior. This is not related to
Network load balancer FailoverPolicy.
Corresponds to the JSON property failoverConfig
3794 3795 3796 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3794 def failover_config @failover_config end |
#isolation_config ⇒ Google::Apis::NetworkservicesV1::ServiceLbPolicyIsolationConfig
Configuration to provide isolation support for the associated Backend Service.
Corresponds to the JSON property isolationConfig
3799 3800 3801 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3799 def isolation_config @isolation_config end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the ServiceLbPolicy resource.
Corresponds to the JSON property labels
3804 3805 3806 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3804 def labels @labels end |
#load_balancing_algorithm ⇒ String
Optional. The type of load balancing algorithm to be used. The default
behavior is WATERFALL_BY_REGION.
Corresponds to the JSON property loadBalancingAlgorithm
3810 3811 3812 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3810 def load_balancing_algorithm @load_balancing_algorithm end |
#name ⇒ String
Identifier. Name of the ServiceLbPolicy resource. It matches pattern projects/
project/locations/location/serviceLbPolicies/service_lb_policy_name`.
Corresponds to the JSON propertyname`
3816 3817 3818 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3816 def name @name end |
#update_time ⇒ String
Output only. The timestamp when this resource was last updated.
Corresponds to the JSON property updateTime
3821 3822 3823 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3821 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 3828 def update!(**args) @auto_capacity_drain = args[:auto_capacity_drain] if args.key?(:auto_capacity_drain) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @failover_config = args[:failover_config] if args.key?(:failover_config) @isolation_config = args[:isolation_config] if args.key?(:isolation_config) @labels = args[:labels] if args.key?(:labels) @load_balancing_algorithm = args[:load_balancing_algorithm] if args.key?(:load_balancing_algorithm) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |