Class: Google::Apis::NetworkservicesV1::TcpRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

TcpRoute is the resource defining how TCP traffic should be routed by a Mesh/ Gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRoute

Returns a new instance of TcpRoute.



4876
4877
4878
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4826
4827
4828
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4826

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4831
4832
4833
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4831

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this TcpRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


4838
4839
4840
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4838

def gateways
  @gateways
end

#labelsHash<String,String>

Optional. Set of label tags associated with the TcpRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4843
4844
4845
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4843

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this TcpRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ The attached Mesh should be of a type SIDECAR Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


4851
4852
4853
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4851

def meshes
  @meshes
end

#nameString

Identifier. Name of the TcpRoute resource. It matches pattern projects/*/ locations/*/tcpRoutes/tcp_route_name>. Corresponds to the JSON property name

Returns:

  • (String)


4857
4858
4859
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4857

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1::TcpRouteRouteRule>

Required. Rules that define how traffic is routed and handled. At least one RouteRule must be supplied. If there are multiple rules then the action taken will be the first rule to match. Corresponds to the JSON property rules



4864
4865
4866
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4864

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


4869
4870
4871
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4869

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4874
4875
4876
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4874

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4881

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end