Class: Google::Apis::NetworkservicesV1::TcpRouteRouteDestination
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::TcpRouteRouteDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
Describe the destination for traffic to be routed to.
Instance Attribute Summary collapse
-
#service_name ⇒ String
Required.
-
#weight ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TcpRouteRouteDestination
constructor
A new instance of TcpRouteRouteDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TcpRouteRouteDestination
Returns a new instance of TcpRouteRouteDestination.
4784 4785 4786 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_name ⇒ String
Required. The URL of a BackendService to route traffic to.
Corresponds to the JSON property serviceName
4769 4770 4771 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4769 def service_name @service_name end |
#weight ⇒ Fixnum
Optional. Specifies the proportion of requests forwarded to the backend
referenced by the serviceName field. This is computed as: - weight/Sum(weights
in this destination list). For non-zero values, there may be some epsilon from
the exact proportion defined here depending on the precision an implementation
supports. If only one serviceName is specified and it has a weight greater
than 0, 100% of the traffic is forwarded to that backend. If weights are
specified for any one service name, they need to be specified for all of them.
If weights are unspecified for all services, then, traffic is distributed in
equal proportions to all of them.
Corresponds to the JSON property weight
4782 4783 4784 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4782 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4789 4790 4791 4792 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4789 def update!(**args) @service_name = args[:service_name] if args.key?(:service_name) @weight = args[:weight] if args.key?(:weight) end |