Class: Google::Apis::NetworkservicesV1::TcpRouteRouteMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. If no routeMatch field is specified, this rule will unconditionally match traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteMatch

Returns a new instance of TcpRouteRouteMatch.



4816
4817
4818
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Required. Must be specified in the CIDR range format. A CIDR range consists of an IP Address and a prefix length to construct the subnet mask. By default, the prefix length is 32 (i.e. matches a single IP address). Only IPV4 addresses are supported. Examples: "10.0.0.1" - matches against this exact IP address. "10.0.0.0/8" - matches against any IP address within the 10.0.0.0 subnet and 255.255.255.0 mask. "0.0.0.0/0" - matches against any IP address'. Corresponds to the JSON property address

Returns:

  • (String)


4809
4810
4811
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4809

def address
  @address
end

#portString

Required. Specifies the destination port to match against. Corresponds to the JSON property port

Returns:

  • (String)


4814
4815
4816
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4814

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4821
4822
4823
4824
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4821

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @port = args[:port] if args.key?(:port)
end