Class: Google::Apis::NetworkservicesV1::TlsRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::TlsRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
TlsRoute defines how traffic should be routed based on SNI and other matching L3 attributes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#target_proxies ⇒ Array<String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsRoute
constructor
A new instance of TlsRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsRoute
Returns a new instance of TlsRoute.
4961 4962 4963 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4903 4904 4905 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4903 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
4908 4909 4910 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4908 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this TlsRoute is attached to, as
one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
4915 4916 4917 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4915 def gateways @gateways end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the TlsRoute resource.
Corresponds to the JSON property labels
4920 4921 4922 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4920 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this TlsRoute is attached to, as one
of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/ The
attached Mesh should be of a type SIDECAR
Corresponds to the JSON property meshes
4928 4929 4930 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4928 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the TlsRoute resource. It matches pattern projects/*/
locations/*/tlsRoutes/tls_route_name>.
Corresponds to the JSON property name
4934 4935 4936 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4934 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteRule>
Required. Rules that define how traffic is routed and handled. At least one
RouteRule must be supplied. If there are multiple rules then the action taken
will be the first rule to match.
Corresponds to the JSON property rules
4941 4942 4943 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4941 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
4946 4947 4948 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4946 def self_link @self_link end |
#target_proxies ⇒ Array<String>
Optional. TargetProxies defines a list of TargetTcpProxies this TlsRoute is
attached to, as one of the routing rules to route the requests served by the
TargetTcpProxy. Each TargetTcpProxy reference should match the pattern:
projects/*/locations/*/targetTcpProxies/
Corresponds to the JSON property targetProxies
4954 4955 4956 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4954 def target_proxies @target_proxies end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4959 4960 4961 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4959 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4966 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @target_proxies = args[:target_proxies] if args.key?(:target_proxies) @update_time = args[:update_time] if args.key?(:update_time) end |