Class: Google::Apis::NetworkservicesV1::TlsRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::TlsRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
TlsRoute defines how traffic should be routed based on SNI and other matching L3 attributes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#target_proxies ⇒ Array<String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsRoute
constructor
A new instance of TlsRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsRoute
Returns a new instance of TlsRoute.
4321 4322 4323 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4263 4264 4265 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4263 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
4268 4269 4270 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4268 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this TlsRoute is attached to, as
one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
4275 4276 4277 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4275 def gateways @gateways end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the TlsRoute resource.
Corresponds to the JSON property labels
4280 4281 4282 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4280 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this TlsRoute is attached to, as one
of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/ The
attached Mesh should be of a type SIDECAR
Corresponds to the JSON property meshes
4288 4289 4290 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4288 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the TlsRoute resource. It matches pattern projects/*/
locations/*/tlsRoutes/tls_route_name>.
Corresponds to the JSON property name
4294 4295 4296 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4294 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1::TlsRouteRouteRule>
Required. Rules that define how traffic is routed and handled. At least one
RouteRule must be supplied. If there are multiple rules then the action taken
will be the first rule to match.
Corresponds to the JSON property rules
4301 4302 4303 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4301 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
4306 4307 4308 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4306 def self_link @self_link end |
#target_proxies ⇒ Array<String>
Optional. TargetProxies defines a list of TargetTcpProxies this TlsRoute is
attached to, as one of the routing rules to route the requests served by the
TargetTcpProxy. Each TargetTcpProxy reference should match the pattern:
projects/*/locations/*/targetTcpProxies/
Corresponds to the JSON property targetProxies
4314 4315 4316 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4314 def target_proxies @target_proxies end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4319 4320 4321 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4319 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4326 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @target_proxies = args[:target_proxies] if args.key?(:target_proxies) @update_time = args[:update_time] if args.key?(:update_time) end |