Class: Google::Apis::NetworkservicesV1::TlsRouteRouteAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

The specifications for routing traffic and applying associated policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteAction

Returns a new instance of TlsRouteRouteAction.



4398
4399
4400
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::NetworkservicesV1::TlsRouteRouteDestination>

Required. The destination services to which traffic should be forwarded. At least one destination service is required. Corresponds to the JSON property destinations



4388
4389
4390
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4388

def destinations
  @destinations
end

#idle_timeoutString

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 1 hour. If set to 0s, the timeout will be disabled. Corresponds to the JSON property idleTimeout

Returns:

  • (String)


4396
4397
4398
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4396

def idle_timeout
  @idle_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4403
4404
4405
4406
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4403

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout)
end