Class: Google::Apis::NetworkservicesV1::TlsRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies how to match traffic and how to route traffic when traffic is matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteRule

Returns a new instance of TlsRouteRouteRule.



5087
5088
5089
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1::TlsRouteRouteAction

The specifications for routing traffic and applying associated policies. Corresponds to the JSON property action



5078
5079
5080
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5078

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1::TlsRouteRouteMatch>

Required. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. Atleast one RouteMatch must be supplied. Corresponds to the JSON property matches



5085
5086
5087
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5085

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5092
5093
5094
5095
# File 'lib/google/apis/networkservices_v1/classes.rb', line 5092

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end