Class: Google::Apis::NetworkservicesV1::TlsRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies how to match traffic and how to route traffic when traffic is matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteRule

Returns a new instance of TlsRouteRouteRule.



4487
4488
4489
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1::TlsRouteRouteAction

The specifications for routing traffic and applying associated policies. Corresponds to the JSON property action



4478
4479
4480
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4478

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1::TlsRouteRouteMatch>

Required. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. Atleast one RouteMatch must be supplied. Corresponds to the JSON property matches



4485
4486
4487
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4485

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4492
4493
4494
4495
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4492

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end