Class: Google::Apis::NetworkservicesV1::TlsRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

Specifies how to match traffic and how to route traffic when traffic is matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteRule

Returns a new instance of TlsRouteRouteRule.



4438
4439
4440
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1::TlsRouteRouteAction

The specifications for routing traffic and applying associated policies. Corresponds to the JSON property action



4429
4430
4431
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4429

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1::TlsRouteRouteMatch>

Required. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. Atleast one RouteMatch must be supplied. Corresponds to the JSON property matches



4436
4437
4438
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4436

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4443
4444
4445
4446
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4443

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end