Class: Google::Apis::NetworkservicesV1::WasmPlugin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb

Overview

WasmPlugin is a resource representing a service executing a customer- provided Wasm module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WasmPlugin

Returns a new instance of WasmPlugin.



4537
4538
4539
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4478
4479
4480
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4478

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4483
4484
4485
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4483

def description
  @description
end

#labelsHash<String,String>

Optional. Set of labels associated with the WasmPlugin resource. The format must comply with the following requirements. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4490
4491
4492
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4490

def labels
  @labels
end

#log_configGoogle::Apis::NetworkservicesV1::WasmPluginLogConfig

Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging. Corresponds to the JSON property logConfig



4496
4497
4498
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4496

def log_config
  @log_config
end

#main_version_idString

Optional. The ID of the WasmPluginVersion resource that is the currently serving one. The version referred to must be a child of this WasmPlugin resource. Corresponds to the JSON property mainVersionId

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4503

def main_version_id
  @main_version_id
end

#nameString

Identifier. Name of the WasmPlugin resource in the following format: projects/project/locations/location/wasmPlugins/wasm_plugin`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4509
4510
4511
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4509

def name
  @name
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4514
4515
4516
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4514

def update_time
  @update_time
end

#used_byArray<Google::Apis::NetworkservicesV1::WasmPluginUsedBy>

Output only. List of all extensions that use this WasmPlugin resource. Corresponds to the JSON property usedBy



4520
4521
4522
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4520

def used_by
  @used_by
end

#versionsHash<String,Google::Apis::NetworkservicesV1::WasmPluginVersionDetails>

Optional. All versions of this WasmPlugin resource in the key-value format. The key is the resource ID, and the value is the VersionDetails object. Lets you create or update a WasmPlugin resource and its versions in a single request. When the main_version_id field is not empty, it must point to one of the VersionDetails objects in the map. If provided in a PATCH request, the new versions replace the previous set. Any version omitted from the versions field is removed. Because the WasmPluginVersion resource is immutable, if a WasmPluginVersion resource with the same name already exists and differs, the request fails. Note: In a GET request, this field is populated only if the field GetWasmPluginRequest.view is set to WASM_PLUGIN_VIEW_FULL. Corresponds to the JSON property versions



4535
4536
4537
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4535

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4542

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @log_config = args[:log_config] if args.key?(:log_config)
  @main_version_id = args[:main_version_id] if args.key?(:main_version_id)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @used_by = args[:used_by] if args.key?(:used_by)
  @versions = args[:versions] if args.key?(:versions)
end