Class: Google::Apis::NetworkservicesV1::WasmPluginVersion
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1::WasmPluginVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1/classes.rb,
lib/google/apis/networkservices_v1/representations.rb,
lib/google/apis/networkservices_v1/representations.rb
Overview
A single immutable version of a WasmPlugin resource. Defines the Wasm module
used and optionally its runtime config.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#image_digest ⇒ String
Output only.
-
#image_uri ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#plugin_config_data ⇒ String
Configuration for the plugin.
-
#plugin_config_digest ⇒ String
Output only.
-
#plugin_config_uri ⇒ String
URI of the plugin configuration stored in the Artifact Registry.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WasmPluginVersion
constructor
A new instance of WasmPluginVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WasmPluginVersion
Returns a new instance of WasmPluginVersion.
4711 4712 4713 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4627 4628 4629 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4627 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
4632 4633 4634 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4632 def description @description end |
#image_digest ⇒ String
Output only. This field holds the digest (usually checksum) value for the
plugin image. The value is calculated based on the image_uri field. If the
image_uri field refers to a container image, the digest value is obtained
from the container image. If the image_uri field refers to a generic
artifact, the digest value is calculated based on the contents of the file.
Corresponds to the JSON property imageDigest
4641 4642 4643 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4641 def image_digest @image_digest end |
#image_uri ⇒ String
Optional. URI of the image containing the Wasm module, stored in Artifact
Registry. The URI can refer to one of the following repository formats: *
Container images: the image_uri must point to a container that contains a
single file with the name plugin.wasm. When a new WasmPluginVersion
resource is created, the digest of the image is saved in the image_digest
field. When pulling a container image from Artifact Registry, the digest value
is used instead of an image tag. * Generic artifacts: the image_uri must be
in this format: projects/project/locations/location/repositories/
repository/ genericArtifacts/package:version`. The specified package and
version must contain a file with the nameplugin.wasm. When a new
WasmPluginVersionresource is created, the checksum of the contents of the
file is saved in theimage_digestfield.
Corresponds to the JSON propertyimageUri`
4657 4658 4659 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4657 def image_uri @image_uri end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the WasmPluginVersion resource.
Corresponds to the JSON property labels
4662 4663 4664 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4662 def labels @labels end |
#name ⇒ String
Identifier. Name of the WasmPluginVersion resource in the following format:
projects/project/locations/location/wasmPlugins/wasm_plugin/ versions/
wasm_plugin_version`.
Corresponds to the JSON propertyname`
4669 4670 4671 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4669 def name @name end |
#plugin_config_data ⇒ String
Configuration for the plugin. The configuration is provided to the plugin at
runtime through the ON_CONFIGURE callback. When a new WasmPluginVersion
resource is created, the digest of the contents is saved in the
plugin_config_digest field.
Corresponds to the JSON property pluginConfigData
NOTE: Values are automatically base64 encoded/decoded in the client library.
4678 4679 4680 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4678 def plugin_config_data @plugin_config_data end |
#plugin_config_digest ⇒ String
Output only. This field holds the digest (usually checksum) value for the
plugin configuration. The value is calculated based on the contents of
plugin_config_data field or the image defined by the plugin_config_uri
field.
Corresponds to the JSON property pluginConfigDigest
4686 4687 4688 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4686 def plugin_config_digest @plugin_config_digest end |
#plugin_config_uri ⇒ String
URI of the plugin configuration stored in the Artifact Registry. The
configuration is provided to the plugin at runtime through the ON_CONFIGURE
callback. The URI can refer to one of the following repository formats: *
Container images: the plugin_config_uri must point to a container that
contains a single file with the name plugin.config. When a new
WasmPluginVersion resource is created, the digest of the image is saved in
the plugin_config_digest field. When pulling a container image from Artifact
Registry, the digest value is used instead of an image tag. * Generic
artifacts: the plugin_config_uri must be in this format: projects/project/
locations/location/repositories/repository/ genericArtifacts/package:
version`. The specified package and version must contain a file with the name
plugin.config. When a newWasmPluginVersionresource is created, the
checksum of the contents of the file is saved in theplugin_config_digest
field.
Corresponds to the JSON propertypluginConfigUri`
4704 4705 4706 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4704 def plugin_config_uri @plugin_config_uri end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4709 4710 4711 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4709 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 |
# File 'lib/google/apis/networkservices_v1/classes.rb', line 4716 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @image_digest = args[:image_digest] if args.key?(:image_digest) @image_uri = args[:image_uri] if args.key?(:image_uri) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @plugin_config_data = args[:plugin_config_data] if args.key?(:plugin_config_data) @plugin_config_digest = args[:plugin_config_digest] if args.key?(:plugin_config_digest) @plugin_config_uri = args[:plugin_config_uri] if args.key?(:plugin_config_uri) @update_time = args[:update_time] if args.key?(:update_time) end |